@@ -1,36 +1,28 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
+ ***************************************************************************/
+/***************************************************************************
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
+ *   Contributors :                                                        *
+ *       NAME <MAIL@ADRESS>                                                *
+ *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
 #include <QtPlugin>
 #include <QApplication>
@@ -100,7 +92,7 @@ static inline QString getPluginPaths()
 
 #ifdef RELEASE
 #ifdef LINUX_INTEGRATED
-    return QString("/usr/%1/%2").arg(LIBRARY_BASENAME).arg(BINARY_NAME);
+    return QString("/usr/%1/%2").arg(LIBRARY_BASENAME).arg(QString(BINARY_NAME).toLower());
 #endif
 
 
@@ -140,13 +132,13 @@ int main( int argc, char *argv[] )
 
     // Add some debugging informations
     defineLibraryPaths();
-    Utils::Log::addMessage("Main","looking for libraries in path : " + qApp->libraryPaths().join(";"));
-    Utils::Log::addMessage("Main","Command line : " + qApp->arguments().join(" "));
+    LOG_FOR("Main","looking for libraries in path : " + qApp->libraryPaths().join(";"));
+    LOG_FOR("Main","Command line : " + qApp->arguments().join(" "));
     Utils::Database::logAvailableDrivers();
 
-    QLibrary mysql("/Developer/Applications/Qt/plugins/sqldrivers/libqsqlmysql.dylib");
-    mysql.load();
-    qWarning() << mysql.errorString() << mysql.isLoaded();
+//    QLibrary mysql("/Developer/Applications/Qt/plugins/sqldrivers/libqsqlmysql.dylib");
+//    mysql.load();
+//    qWarning() << mysql.errorString() << mysql.isLoaded();
 
 
     QTextCodec::setCodecForTr( QTextCodec::codecForName( "UTF-8" ) );
@@ -163,7 +155,7 @@ int main( int argc, char *argv[] )
         return 0;
     }
 
-    Utils::Log::addMessage("Main", qApp->arguments().join(";"));
+    LOG_FOR("Main", qApp->arguments().join(";"));
 
     ExtensionSystem::PluginManager pluginManager;
     pluginManager.setFileExtension(QString("pluginspec"));
@@ -172,12 +164,12 @@ int main( int argc, char *argv[] )
     pluginManager.setPluginPaths(QStringList() << pluginPaths);
 
 #ifdef DEBUG
-    Utils::Log::addMessage("Main", "Running debug version");
+    LOG_FOR("Main", "Running debug version");
 #else
-    Utils::Log::addMessage("Main", "Running release version");
+    LOG_FOR("Main", "Running release version");
 #endif
 #ifdef LINUX_INTEGRATED
-    Utils::Log::addMessage("Main", "Linux Integrated");
+    LOG_FOR("Main", "Linux Integrated");
 #endif
 
 //    const QStringList arguments = app.arguments();
