@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -35,7 +35,6 @@
 #include <coreplugin/dialogs/helpdialog.h>
 #include <coreplugin/ipatient.h>
 #include <coreplugin/idocumentprinter.h>
-
 #include <coreplugin/coreimpl.h>
 #include <coreplugin/commandlineparser.h>
 
@@ -49,7 +48,8 @@
 #include <drugsbaseplugin/drugsbase.h>
 #include <drugsbaseplugin/globaldrugsmodel.h>
 #include <drugsbaseplugin/drugsmodel.h>
-#include <drugsbaseplugin/interactionsmanager.h>
+#include <drugsbaseplugin/interactionmanager.h>
+#include <drugsbaseplugin/engines/allergyengine.h>
 
 #include <templatesplugin/templatesview.h>
 
@@ -62,6 +62,7 @@
 #include <utils/global.h>
 #include <utils/updatechecker.h>
 #include <utils/iconbadgealert.h>
+#include <extensionsystem/pluginmanager.h>
 
 #include "ui_mainwindow.h"
 
@@ -88,7 +89,7 @@ using namespace Trans::ConstantTranslations;
 // Getting the Core instances
 static inline Utils::UpdateChecker *updateChecker() { return Core::ICore::instance()->updateChecker(); }
 static inline Core::ContextManager *contextManager() { return Core::ICore::instance()->contextManager(); }
-static inline Core::CommandLine *commandLine() { return Core::ICore::instance()->commandLine(); }
+static inline Core::ICommandLine *commandLine() { return Core::ICore::instance()->commandLine(); }
 static inline Core::ISettings *settings()  { return Core::ICore::instance()->settings(); }
 static inline Core::ITheme *theme()  { return Core::ICore::instance()->theme(); }
 static inline Core::ActionManager *actionManager() { return Core::ICore::instance()->actionManager(); }
@@ -97,6 +98,7 @@ static inline Core::FileManager *fileManager() { return Core::ICore::instance()-
 inline static DrugsDB::DrugsModel *drugModel() { return DrugsWidget::DrugsWidgetManager::instance()->currentDrugsModel(); }
 static inline Core::IDocumentPrinter *printer() {return ExtensionSystem::PluginManager::instance()->getObject<Core::IDocumentPrinter>();}
 static inline DrugsDB::Internal::DrugsBase *drugsBase() {return DrugsDB::Internal::DrugsBase::instance();}
+static inline ExtensionSystem::PluginManager *pluginManager() {return ExtensionSystem::PluginManager::instance();}
 
 // SplashScreen Messagers
 static inline void messageSplash(const QString &s) {theme()->messageSplashScreen(s); }
@@ -109,8 +111,11 @@ namespace Internal {
 class MainWinPrivate {
 public:
     MainWinPrivate(MainWindow *parent) :
-            m_Mapper(0), m_AllergiesModel(0), m_AllergiesView(0), m_PrecautionView(0),
-            m_TemplatesDock(0), m_PrecautionsDock(0), m_NameOrder(-1), q(parent)
+        m_Mapper(0), m_AllergiesModel(0), m_AllergiesView(0), m_PrecautionView(0),
+        m_TemplatesDock(0),
+//        m_PrecautionsDock(0),
+        m_NameOrder(-1),
+        q(parent)
     {}
 
     ~MainWinPrivate()
@@ -136,21 +141,22 @@ public:
             QString tmp;
             if (QFile(exfile).exists())
                 tmp = Utils::readTextFile(exfile, Utils::DontWarnUser);
-            //            Utils::Log::addMessage(this, "Content of the exchange file : " + tmp);
+            //            LOG("Content of the exchange file : " + tmp);
+            DrugsDB::DrugsIO io;
             if (tmp.contains(DrugsDB::Constants::ENCODEDHTML_FREEDIAMSTAG)) {
                 int begin = tmp.indexOf(DrugsDB::Constants::ENCODEDHTML_FREEDIAMSTAG) + QString(DrugsDB::Constants::ENCODEDHTML_FREEDIAMSTAG).length();
                 int end = tmp.indexOf("\"", begin);
                 QString encoded = tmp.mid( begin, end - begin );
-                DrugsDB::DrugsIO::instance()->prescriptionFromXml(drugModel(), QByteArray::fromBase64(encoded.toAscii()));
+                io.prescriptionFromXml(drugModel(), QByteArray::fromBase64(encoded.toAscii()));
             } else if (tmp.contains("DrugsInteractionsEncodedPrescription:")) {
                 /** \todo Manage wrong file encoding */
                 int begin = tmp.indexOf("DrugsInteractionsEncodedPrescription:") + QString("DrugsInteractionsEncodedPrescription:").length();
                 int end = tmp.indexOf("\"", begin);
                 QString encoded = tmp.mid( begin, end - begin );
-                DrugsDB::DrugsIO::instance()->prescriptionFromXml(drugModel(), QByteArray::fromBase64(encoded.toAscii()));
+                io.prescriptionFromXml(drugModel(), QByteArray::fromBase64(encoded.toAscii()));
             } else if (tmp.startsWith("<?xml") && tmp.contains("<FreeDiams>", Qt::CaseInsensitive) && tmp.contains("</FreeDiams>", Qt::CaseInsensitive)) {
                 /** \todo Read patients datas ? */
-                DrugsDB::DrugsIO::instance()->prescriptionFromXml(drugModel(), tmp);
+                io.prescriptionFromXml(drugModel(), tmp);
             } else {
                 return false;
             }
@@ -180,8 +186,12 @@ public:
 
     void createPrecautionsModelAndView(QTreeView *treeview, QComboBox *combo)
     {
-        QStandardItemModel *model = DrugsDB::GlobalDrugsModel::drugsPrecautionsModel();
-        // Create the view
+        DrugsDB::Internal::DrugAllergyEngine *engine = pluginManager()->getObject<DrugsDB::Internal::DrugAllergyEngine>();
+        if (!engine) {
+            LOG_ERROR_FOR("MainWindow", "No allergy engine");
+            return;
+        }
+        QAbstractItemModel *model = engine->drugPrecautionModel();
         if (!treeview) {
             treeview = new QTreeView(q);
             combo->setModel(model);
@@ -200,7 +210,7 @@ public:
     QStandardItemModel *m_AllergiesModel;
     QTreeView *m_AllergiesView;
     QTreeView *m_PrecautionView;
-    QDockWidget *m_TemplatesDock, *m_PrecautionsDock;
+    QDockWidget *m_TemplatesDock; //, *m_PrecautionsDock;
     int m_NameOrder;
 
 private:
@@ -210,8 +220,9 @@ private:
 static bool transmitDosage()
 {
     if (!Utils::isDebugCompilation()) {
-        Utils::Log::addMessage("Core", QCoreApplication::translate("MainWindow", "Preparing dosage transmission"));
-        DrugsDB::DrugsIO::instance()->startsDosageTransmission();
+        LOG_FOR("Core", QCoreApplication::translate("MainWindow", "Preparing dosage transmission"));
+        /** \todo code here */
+//        DrugsDB::DrugsIO::instance()->startsDosageTransmission();
     }
     return true;
 }
@@ -374,7 +385,7 @@ void MainWindow::extensionsInitialized()
     // SelectionOnly ?
     if (commandLine()->value(Core::CommandLine::CL_SelectionOnly).toBool()) {
         // Log mode
-        Utils::Log::addMessage(this, tr("Entering selection mode"));
+        LOG(tr("Entering selection mode"));
         // Unable some actions in menus
     //    aPrint->setEnabled(false);
     //    aPrintPreview->setEnabled(false);
@@ -384,14 +395,13 @@ void MainWindow::extensionsInitialized()
 
     // If needed read exchange file
     if (!d->readExchangeFile(tr("Reading exchange file..."))) {
-        Utils::Log::addError(this, tkTr(Trans::Constants::FILE_1_ISNOT_READABLE).arg(commandLine()->value(Core::CommandLine::CL_ExchangeOutFile).toString()),
-                             __FILE__, __LINE__);
+        LOG_ERROR(tkTr(Trans::Constants::FILE_1_ISNOT_READABLE).arg(commandLine()->value(Core::CommandLine::CL_ExchangeOutFile).toString()));
     }
 
     // Start the update checker
     if (updateChecker()->needsUpdateChecking(settings()->getQSettings())) {
         messageSplash(tkTr(Trans::Constants::CHECKING_UPDATES));
-        Utils::Log::addMessage(this, tkTr(Trans::Constants::CHECKING_UPDATES));
+        LOG(tkTr(Trans::Constants::CHECKING_UPDATES));
         statusBar()->addWidget(new QLabel(tkTr(Trans::Constants::CHECKING_UPDATES), this));
         statusBar()->addWidget(updateChecker()->progressBar(this),1);
         connect(updateChecker(), SIGNAL(updateFound()), this, SLOT(updateFound()));
@@ -420,7 +430,6 @@ void MainWindow::extensionsInitialized()
     }
 
     createDockWindows();
-    finishSplash(this);
     readSettings();
     show();
     raise();
@@ -438,10 +447,10 @@ MainWindow::~MainWindow()
         delete d->m_TemplatesDock;
         d->m_TemplatesDock = 0;
     }
-    if (d->m_PrecautionsDock) {
-        delete d->m_PrecautionsDock;
-        d->m_PrecautionsDock = 0;
-    }
+//    if (d->m_PrecautionsDock) {
+//        delete d->m_PrecautionsDock;
+//        d->m_PrecautionsDock = 0;
+//    }
     if (d)
         delete d;
     d = 0;
@@ -454,6 +463,7 @@ void MainWindow::postCoreInitialization()
     actionManager()->retranslateMenusAndActions();
     refreshPatient();
     updateIconBadgeOnMacOs();
+    finishSplash(this);
 }
 
 /**
@@ -475,10 +485,11 @@ void MainWindow::refreshPatient()
 void MainWindow::updateIconBadgeOnMacOs()
 {
 #ifdef Q_OS_MAC
-    int n = drugModel()->interactionsManager()->getAllInteractionsFound().count();
-    if (n > 0) {
-        Utils::MacOs::setIconBadgeLabel(QString::number(n));
-    }
+    /** \todo code here : move this in the interactionmanager; result or alert  ? */
+//    int n = drugModel()->interactionsManager()->getAllInteractionsFound().count();
+//    if (n > 0) {
+//        Utils::MacOs::setIconBadgeLabel(QString::number(n));
+//    }
 #endif
 }
 
@@ -521,7 +532,7 @@ void MainWindow::changePatientNameLabelOrder(const int first)
 */
 void MainWindow::closeEvent(QCloseEvent *event)
 {
-    Utils::Log::addMessage(this, "Closing MainWindow");
+    LOG("Closing MainWindow");
     Core::ICore::instance()->requestSaveSettings();
 
     //    const QList<ICoreListener *> listeners =
@@ -536,9 +547,9 @@ void MainWindow::closeEvent(QCloseEvent *event)
     // Save exchange file
     QString exfile = commandLine()->value(Core::CommandLine::CL_ExchangeOutFile).toString();
     if (!exfile.isEmpty()) {
-        Utils::Log::addMessage(this, QString("Exchange File : %1 - %2")
-                               .arg(exfile)
-                               .arg(commandLine()->value(Core::CommandLine::CL_EMR_Name).toString()));
+        LOG(QString("Exchange File : %1 - %2")
+            .arg(exfile)
+            .arg(commandLine()->value(Core::CommandLine::CL_EMR_Name).toString()));
         QString format = commandLine()->value(Core::CommandLine::CL_ExchangeOutFileFormat).toString();
         QString tmp;
 
@@ -557,10 +568,11 @@ void MainWindow::closeEvent(QCloseEvent *event)
         extraDatas.prepend(QString("<DateOfCreation>%1</DateOfCreation>").arg(QDateTime::currentDateTime().toString(Qt::ISODate)));
 
         // Manage specific MedinTux output exchange file format
+        DrugsDB::DrugsIO io;
         if (commandLine()->value(Core::CommandLine::CL_MedinTux).toBool() ||
             commandLine()->value(Core::CommandLine::CL_EMR_Name).toString().compare("medintux",Qt::CaseInsensitive) == 0) {
             if (format=="html_xml" || format=="html") {
-                tmp = DrugsDB::DrugsIO::instance()->prescriptionToHtml(drugModel(), extraDatas, DrugsDB::DrugsIO::MedinTuxVersion);
+                tmp = io.prescriptionToHtml(drugModel(), extraDatas, DrugsDB::DrugsIO::MedinTuxVersion);
                 tmp.replace("font-weight:bold;", "font-weight:600;");
                 Utils::saveStringToFile(Utils::toHtmlAccent(tmp), exfile, Utils::Overwrite, Utils::DontWarnUser);
             } else if (format=="xml") {
@@ -568,7 +580,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
             }
         } else {
             if (format=="html_xml" || format=="html") {
-                tmp = DrugsDB::DrugsIO::instance()->prescriptionToHtml(drugModel(), extraDatas, DrugsDB::DrugsIO::MedinTuxVersion);
+                tmp = io.prescriptionToHtml(drugModel(), extraDatas, DrugsDB::DrugsIO::MedinTuxVersion);
                 Utils::saveStringToFile(Utils::toHtmlAccent(tmp), exfile, Utils::Overwrite, Utils::DontWarnUser);
             } else if (format=="xml") {
                 savePrescription(exfile);
@@ -790,7 +802,8 @@ bool MainWindow::savePrescription(const QString &fileName)
         extraDatas.append("/>");
     }
 //    qWarning() << extraDatas;
-    return DrugsDB::DrugsIO::savePrescription(drugModel(), extraDatas, fileName);
+    DrugsDB::DrugsIO io;
+    return io.savePrescription(drugModel(), extraDatas, fileName);
 }
 
 /**
@@ -816,6 +829,7 @@ bool MainWindow::openFile()
 void MainWindow::readFile(const QString &file)
 {
     QString datas;
+    DrugsDB::DrugsIO io;
     if (drugModel()->rowCount() > 0) {
         int r = Utils::withButtonsMessageBox(
                 tr("Opening a prescription : merge or replace ?"),
@@ -823,12 +837,12 @@ void MainWindow::readFile(const QString &file)
                 QString(), QStringList() << tr("Replace prescription") << tr("Add to prescription"),
                 tr("Open a prescription") + " - " + qApp->applicationName());
         if (r == 0) {
-            DrugsDB::DrugsIO::loadPrescription(drugModel(), file, datas, DrugsDB::DrugsIO::ReplacePrescription);
+            io.loadPrescription(drugModel(), file, datas, DrugsDB::DrugsIO::ReplacePrescription);
         } else if (r==1) {
-            DrugsDB::DrugsIO::loadPrescription(drugModel(), file, datas, DrugsDB::DrugsIO::AppendPrescription);
+            io.loadPrescription(drugModel(), file, datas, DrugsDB::DrugsIO::AppendPrescription);
         }
     } else {
-        DrugsDB::DrugsIO::loadPrescription(drugModel(), file, datas, DrugsDB::DrugsIO::ReplacePrescription);
+        io.loadPrescription(drugModel(), file, datas, DrugsDB::DrugsIO::ReplacePrescription);
     }
     // Process patient's data only if not blockDatas and not using exchange-in file
     if ((!commandLine()->value(Core::CommandLine::CL_BlockPatientDatas).toBool()) &&
@@ -849,21 +863,30 @@ void MainWindow::createDockWindows()
     menu->addAction(dock->toggleViewAction());
 
     // Create patient's precautions dock
-    dock = d->m_PrecautionsDock = new QDockWidget(tkTr(Trans::Constants::PATIENT_INFORMATION), this);
-    dock->setObjectName("precautionsDock");
-    dock->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
-    addDockWidget(Qt::RightDockWidgetArea, dock);
-    d->m_PrecautionView = new QTreeView(dock);
-    d->m_PrecautionView->header()->hide();
-    d->m_PrecautionView->expandAll();
-    d->m_PrecautionView->setModel(DrugsDB::GlobalDrugsModel::drugsPrecautionsModel());
-    dock->setWidget(d->m_PrecautionView);
-    // aShowPrecautionsDock
-    QAction *a = dock->toggleViewAction();
-    a->setObjectName("aShowPrecautionsDock");
-    Core::Command *cmd = actionManager()->registerAction(a, "aShowPrecautionsDock", QList<int>() << Core::Constants::C_GLOBAL_ID);
-    cmd->setTranslations(tr("Toggle patient's precautions"));
-    Core::ActionContainer *plugmenu = actionManager()->actionContainer(DrugsWidget::Constants::M_PLUGINS_DRUGS);
-    plugmenu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_VIEWS);
+//    dock = d->m_PrecautionsDock = new QDockWidget(tkTr(Trans::Constants::PATIENT_INFORMATION), this);
+//    dock->setObjectName("precautionsDock");
+//    dock->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
+//    addDockWidget(Qt::RightDockWidgetArea, dock);
+
+//    DrugsDB::Internal::DrugAllergyEngine *engine = pluginManager()->getObject<DrugsDB::Internal::DrugAllergyEngine>();
+//    if (!engine) {
+//        LOG_ERROR_FOR("MainWindow", "No allergy engine");
+//        return;
+//    }
+//    QAbstractItemModel *model = engine->drugPrecautionModel();
+
+//    d->m_PrecautionView = new QTreeView(dock);
+//    d->m_PrecautionView->setModel(model);
+//    d->m_PrecautionView->header()->hide();
+//    d->m_PrecautionView->expandAll();
+//    d->m_PrecautionView->setEditTriggers(QAbstractItemView::NoEditTriggers);
+//    dock->setWidget(d->m_PrecautionView);
+//    // aShowPrecautionsDock
+//    QAction *a = dock->toggleViewAction();
+//    a->setObjectName("aShowPrecautionsDock");
+//    Core::Command *cmd = actionManager()->registerAction(a, "aShowPrecautionsDock", QList<int>() << Core::Constants::C_GLOBAL_ID);
+//    cmd->setTranslations(tr("Toggle patient's precautions"));
+//    Core::ActionContainer *plugmenu = actionManager()->actionContainer(DrugsWidget::Constants::M_PLUGINS_DRUGS);
+//    plugmenu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_VIEWS);
 }
 
