@@ -32,13 +32,7 @@ Please verify your daily scheme prescriptions and relations to meal.</source>
 <context>
     <name>DrugsBase</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="999"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1049"/>
-        <source>ERROR : will retreiving %1. Wrong number of fields</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/interactionsbase.cpp" line="326"/>
+        <location filename="../../plugins/drugsbaseplugin/engines/drugdruginteractionengine.cpp" line="975"/>
         <source>FreeDiams Interactions Engine</source>
         <translation type="unfinished"></translation>
     </message>
@@ -46,121 +40,98 @@ Please verify your daily scheme prescriptions and relations to meal.</source>
 <context>
     <name>DrugsDB::AtcTreeModel</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/atctreemodel.cpp" line="329"/>
+        <location filename="../../plugins/drugsbaseplugin/atctreemodel.cpp" line="341"/>
         <source>Label</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/atctreemodel.cpp" line="331"/>
+        <location filename="../../plugins/drugsbaseplugin/atctreemodel.cpp" line="343"/>
         <source>Code</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>DrugsDB::DrugsBasePlugin</name>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsbaseplugin.cpp" line="115"/>
+        <source>Initializing drugs database plugin...</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DrugsDB::DrugsIO</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="253"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="538"/>
         <source>Dosages transmitted.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="256"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="541"/>
         <source>Dosage not correctly transmitted</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="290"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="323"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="583"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="602"/>
         <source>You are trying to read a corrupted XML file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="291"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="584"/>
         <source>Error: %1
 Line: %2, Column: %3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="321"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="601"/>
         <source>Unable to load XML prescription : tag %1 is missing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="308"/>
-        <source>Prescription specifies a different drugs database than the actual one.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="309"/>
-        <source>You are trying to load prescription that uses a different drugs database than the actual one. You can not read this prescription unless you change the current database in the Preferences.
-Actual: %1
-Prescription: %2.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="324"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="603"/>
         <source>Missing tag: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="351"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="361"/>
-        <source>  * %1 was added as a textual drug.
-</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="370"/>
-        <source>  * %1 (%2) is already in the prescription. Drug is ignored.
-</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="378"/>
-        <source>  * %1 (%2) was added as a textual drug.
-</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="410"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="653"/>
         <source>Interaction checking will not take these drugs into account.
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="411"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="654"/>
         <source>FreeDiams encountered errors while reading the XML prescription.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="419"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="665"/>
         <source>Xml prescription correctly read.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="452"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="697"/>
         <source>No file name passed to load prescription</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="626"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="871"/>
         <source>Save test only drugs too ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="627"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="872"/>
         <source>Drugs added for testing only are actually hidden in this prescription.
 Do you want to add them to the file ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="629"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="874"/>
         <source>Answering &apos;no&apos; will cause definitive lost of test only drugs when reloading this file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="822"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="836"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="1093"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="1107"/>
         <source>Drugs Prescription</source>
         <translation type="unfinished"></translation>
     </message>
@@ -168,7 +139,7 @@ Do you want to add them to the file ?</source>
 <context>
     <name>DrugsDB::DrugsModel</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="498"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="515"/>
         <source>KNOWN ALLERGY</source>
         <translation type="unfinished"></translation>
     </message>
@@ -176,276 +147,303 @@ Do you want to add them to the file ?</source>
 <context>
     <name>DrugsDB::GlobalDrugsModel</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="742"/>
+        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="390"/>
         <source>KNOWN ALLERGY</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="746"/>
+        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="394"/>
         <source>KNOWN INTOLERANCE</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="784"/>
+        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="434"/>
         <source>Identifier(s): </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="782"/>
+        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="432"/>
         <source>Form(s): </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="783"/>
+        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="433"/>
         <source>Route(s): </source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>DrugsDB::InteractionsManager</name>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="334"/>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="368"/>
-        <source>Nature of the risk: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="339"/>
-        <source>What to do: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="348"/>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="382"/>
-        <source>Interaction(s) Found : </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="373"/>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="428"/>
-        <source>Management: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="421"/>
-        <source>Nature of the risk</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>DrugsDB::Internal::DosageModel</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="135"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="134"/>
         <source>complet tab.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="136"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="135"/>
         <source>half tab.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="137"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="136"/>
         <source>quater tab.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="141"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="140"/>
         <source>dose per kilograms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="142"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="141"/>
         <source>reference spoon</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="143"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="142"/>
         <source>2.5 ml spoon</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="144"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="143"/>
         <source>5 ml spoon</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="145"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="144"/>
         <source>puffs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="146"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="145"/>
         <source>dose</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="147"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="146"/>
         <source>mouthwash</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="148"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="147"/>
         <source>inhalation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="149"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="148"/>
         <source>application</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="150"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="149"/>
         <source>washing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="151"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="150"/>
         <source>shampooing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="152"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="151"/>
         <source>eyewash</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="153"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="152"/>
         <source>instillation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="154"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="153"/>
         <source>pulverization</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="314"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="344"/>
         <source>Model Error : unable to insert a row</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="476"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="508"/>
         <source>The intakes&apos; scheme must be defined.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="478"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="510"/>
         <source>The period&apos;s scheme must be defined.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="481"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="513"/>
         <source>The duration&apos;s scheme must be defined.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>DrugsDB::Internal::DrugAllergyEngine</name>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/engines/allergyengine.cpp" line="514"/>
+        <source>Detects allergies and intolerances to medications</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DrugsDB::Internal::DrugDrugInteractionEngine</name>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/engines/drugdruginteractionengine.cpp" line="824"/>
+        <source>Detects interaction between drugs</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DrugsDB::Internal::DrugsBase</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="307"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="619"/>
         <source>Searching databases into dir %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="357"/>
-        <source>WARNING : can not open database %1 : %2 
- %3 </source>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="632"/>
+        <source>No drugs database found.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="599"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="605"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="610"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="643"/>
+        <source>Drug database source does not exists.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="644"/>
+        <source>Switching to the default drugs database source.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="991"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="997"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1002"/>
         <source>Unable to create the Protocol database.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="599"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="605"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="610"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="991"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="997"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1002"/>
         <source>Please contact dev team.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="722"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1115"/>
         <source>Unable to update the protocol&apos;s transmission date.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1344"/>
+        <source>No drug database source selected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1346"/>
+        <source>No drugs database loaded.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1364"/>
+        <source>Asking for a drug without UID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1500"/>
+        <source>Unable to find drug with DID %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DrugsDB::Internal::DrugsTemplatePrinter</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="65"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="66"/>
         <source>Warning : </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="67"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="68"/>
         <source>Interactions found. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="69"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="70"/>
         <source>Allergies found. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="74"/>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="79"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="75"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="80"/>
         <source>What do you want to do ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="87"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="88"/>
         <source>Synthetic interactions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="100"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="101"/>
         <source>Print separately or merge printing.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="101"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="102"/>
         <source>You have selected multiple templates, would you print them separately or merge templates for printing on a single order ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="104"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="105"/>
         <source>Print separately</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="104"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="105"/>
         <source>Merge and print</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>DrugsDB::Internal::PimEngine</name>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/engines/pimengine.cpp" line="767"/>
+        <source>(Experimental)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/engines/pimengine.cpp" line="777"/>
+        <source>Detects interaction between drugs and patient in elderly</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DrugsData</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="586"/>
+        <location filename="../../plugins/drugsbaseplugin/idrug.cpp" line="809"/>
         <source>No INN found.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="591"/>
+        <location filename="../../plugins/drugsbaseplugin/idrug.cpp" line="814"/>
         <source>No interaction class found.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="626"/>
+        <location filename="../../plugins/drugsbaseplugin/idrug.cpp" line="852"/>
         <source>Form(s): </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="627"/>
+        <location filename="../../plugins/drugsbaseplugin/idrug.cpp" line="853"/>
         <source>Route(s): </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="628"/>
+        <location filename="../../plugins/drugsbaseplugin/idrug.cpp" line="854"/>
         <source>Identifier(s): </source>
         <translation type="unfinished"></translation>
     </message>
@@ -453,12 +451,12 @@ Do you want to add them to the file ?</source>
 <context>
     <name>DrugsModel</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="202"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="245"/>
         <source>x %1 of %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="212"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="254"/>
         <source>Available Dosages</source>
         <translation type="unfinished"></translation>
     </message>
@@ -466,12 +464,12 @@ Do you want to add them to the file ?</source>
 <context>
     <name>mfDrugsConstants</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/constants.h" line="76"/>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="80"/>
         <source>&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;[[DRUG]]&lt;/span&gt;&lt;span style=&quot;font-style:italic;&quot;&gt;[&lt;br /&gt;Take [Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][&lt;br /&gt;Route: [ROUTE]][&lt;br /&gt;Daily Distribution: [DISTRIBUTED_DAILY_SCHEME]][&lt;br /&gt;Minimum interval between intakes: [MIN_INTERVAL]][&lt;br /&gt;[NOTE] ]&lt;/span&gt;&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/constants.h" line="84"/>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="88"/>
         <source>[[DRUG]][
 Take [Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][
 Route: [ROUTE]][
@@ -480,5 +478,49 @@ Minimum interval between intakes: [MIN_INTERVAL]][
 [NOTE] ]</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="255"/>
+        <source>Nature of risk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="256"/>
+        <source>Management</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="257"/>
+        <source>Drug-drug interactions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="260"/>
+        <source>DDI</source>
+        <extracomment>This is the short name of the Drug-drug interactions engine.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="262"/>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="266"/>
+        <source>Potentially inappropriate medications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="265"/>
+        <source>PIM</source>
+        <extracomment>This is the short name of the Potentially inappropriate medications engine.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="269"/>
+        <source>Allergy / Intolerances to medications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="272"/>
+        <source>Allergy</source>
+        <extracomment>This is the short name of the Potentially inappropriate medications engine.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
