@@ -96,61 +96,68 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>Templates::Internal::TemplatesPreferencesPage</name>
+    <message>
+        <location filename="../../plugins/templatesplugin/templatespreferencespages.cpp" line="65"/>
+        <source>Templates preferences</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Templates::Internal::TemplatesPreferencesWidget</name>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="43"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="20"/>
         <source>Data saving</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="49"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="26"/>
         <source>Always ask for confirmation before deletion</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="59"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="36"/>
         <source>Presentation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="67"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="44"/>
         <source>Font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="82"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="59"/>
         <source>Always expand categories and templates tree</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="96"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="73"/>
         <source>Category background color</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="122"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="99"/>
         <source>Category foreground color</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="174"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="151"/>
         <source>Template foreground color</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="148"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="125"/>
         <source>Template background color</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="14"/>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="26"/>
         <source>Templates preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="89"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="66"/>
         <source>Lock category view at startup</source>
         <translation type="unfinished"></translation>
     </message>
@@ -171,32 +178,18 @@
 <context>
     <name>Templates::TemplateBase</name>
     <message>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="353"/>
-        <source>Unable to connect the Templates host.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="353"/>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="359"/>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="363"/>
+        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="321"/>
+        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="329"/>
+        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="335"/>
+        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="345"/>
         <source>Please contact dev team.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="359"/>
-        <source>Unable to create the Templates database.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="363"/>
-        <source>Unable to connect the Templates database.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>Templates::TemplatesModel</name>
     <message>
-        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="1021"/>
+        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="1025"/>
         <source>New</source>
         <translation type="unfinished"></translation>
     </message>
