@@ -97,61 +97,68 @@ Répondre &apos;Non&apos; causera une perte de données définitive.</translatio
         <translation>Voir le contenu</translation>
     </message>
 </context>
+<context>
+    <name>Templates::Internal::TemplatesPreferencesPage</name>
+    <message>
+        <location filename="../../plugins/templatesplugin/templatespreferencespages.cpp" line="65"/>
+        <source>Templates preferences</source>
+        <translation>Préférences des modèles</translation>
+    </message>
+</context>
 <context>
     <name>Templates::Internal::TemplatesPreferencesWidget</name>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="43"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="20"/>
         <source>Data saving</source>
         <translation>Sauvegarde des données</translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="49"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="26"/>
         <source>Always ask for confirmation before deletion</source>
         <translation>Toujours demander une confirmation avant la suppression</translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="59"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="36"/>
         <source>Presentation</source>
         <translation>Présentation</translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="67"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="44"/>
         <source>Font</source>
         <translation>Police de caractères</translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="82"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="59"/>
         <source>Always expand categories and templates tree</source>
         <translation>Toujours développer les branches de l&apos;arbre des modèles</translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="96"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="73"/>
         <source>Category background color</source>
         <translation>Couleur de fond des catégories</translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="122"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="99"/>
         <source>Category foreground color</source>
         <translation>Couleur de la police des catégories</translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="174"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="151"/>
         <source>Template foreground color</source>
         <translation>Couleur de fond des modèles</translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="148"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="125"/>
         <source>Template background color</source>
         <translation>Couleur de la police des modèles</translation>
     </message>
     <message>
         <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="14"/>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="26"/>
         <source>Templates preferences</source>
         <translation>Préférences des modèles</translation>
     </message>
     <message>
-        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="89"/>
+        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="66"/>
         <source>Lock category view at startup</source>
         <translation>Verrouiller la vue au démarrage</translation>
     </message>
@@ -172,32 +179,18 @@ Répondre &apos;Non&apos; causera une perte de données définitive.</translatio
 <context>
     <name>Templates::TemplateBase</name>
     <message>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="353"/>
-        <source>Unable to connect the Templates host.</source>
-        <translation>Impossible de se connecter à l&apos;hôte.</translation>
-    </message>
-    <message>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="353"/>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="359"/>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="363"/>
+        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="321"/>
+        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="329"/>
+        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="335"/>
+        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="345"/>
         <source>Please contact dev team.</source>
         <translation>Veuillez contacter l&apos;équipe de développement.</translation>
     </message>
-    <message>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="359"/>
-        <source>Unable to create the Templates database.</source>
-        <translation>Impossible de créer la base de données Modèles.</translation>
-    </message>
-    <message>
-        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="363"/>
-        <source>Unable to connect the Templates database.</source>
-        <translation>Impossible de se connecter à la base de données Modèles.</translation>
-    </message>
 </context>
 <context>
     <name>Templates::TemplatesModel</name>
     <message>
-        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="1021"/>
+        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="1025"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
