@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -33,6 +33,14 @@
 #include <QStringList>
 #include <QHash>
 
+/**
+ * \file multilingualclasstemplate.h
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 15 Mar 2011
+*/
+
+
 namespace Trans {
 
 /**
@@ -70,7 +78,7 @@ public:
     }
 
     /** Use for the debugging treewidget construction */
-    virtual QString categoryForTreeWiget() const = 0;
+    QString categoryForTreeWiget() const {return QString();}
 
     /** Check if the \e lang already exists */
     bool hasLanguage(const QString &lang)
