@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -45,11 +45,24 @@ class QTreeWidget;
 
 /**
  * \file log.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.0.12
- * \date 14 Sept 2009
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.5.0
+ * \date 05 Feb 2011
 */
 
+#define LOG_ERROR_FOR(object, message)  Utils::Log::addError(object, message,__FILE__,__LINE__)
+#define LOG_ERROR(message)              Utils::Log::addError(this, message,__FILE__,__LINE__)
+
+#define LOG_QUERY_ERROR_FOR(object, qsqlquery)  Utils::Log::addQueryError(object, qsqlquery,__FILE__,__LINE__)
+#define LOG_QUERY_ERROR(qsqlquery)              Utils::Log::addQueryError(this, qsqlquery,__FILE__,__LINE__)
+
+#define LOG_FOR(object, message) Utils::Log::addMessage(object, message)
+#define LOG(message) Utils::Log::addMessage(this, message)
+
+#define LOG_DATABASE_FOR(object, message) Utils::Log::addDatabaseLog(object, message,__FILE__,__LINE__)
+#define LOG_DATABASE(message) Utils::Log::addDatabaseLog(this, message,__FILE__,__LINE__)
+
+#define WARN_FUNC qWarning() << Q_FUNC_INFO
 
 namespace Utils {
 
@@ -107,6 +120,9 @@ public:
     static void addQueryError( const QObject * o, const QSqlQuery & q, const QString &file = QString::null, const int line = -1, bool forceWarning = false );
     static void addQueryError( const QString & o, const QSqlQuery & q, const QString &file = QString::null, const int line = -1, bool forceWarning = false );
 
+    static void addDatabaseLog( const QObject * o, const QSqlDatabase & q, const QString &file = QString::null, const int line = -1, bool forceWarning = false );
+    static void addDatabaseLog( const QString & o, const QSqlDatabase & q, const QString &file = QString::null, const int line = -1, bool forceWarning = false );
+
     /** \brief Add a message to tkLog containing the elapsed time of \t and restart it. Used for debugging purpose. */
     static void logTimeElapsed( QTime &t, const QString &object, const QString &forDoingThis );
 
