@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -43,7 +43,7 @@ public:
     QString name() const     { return tr("4. Build informations"); }
     QString category() const { return tr("Application"); }
 
-    QWidget *widget();
+    QWidget *createPage(QWidget *parent = 0);
 };
 
 class LicenseAboutPage : public IAboutPage
@@ -57,7 +57,7 @@ public:
     QString name() const     { return tr("3. License"); }
     QString category() const { return tr("Application"); }
 
-    QWidget *widget();
+    QWidget *createPage(QWidget *parent);
 };
 
 class TeamAboutPage : public IAboutPage
@@ -71,7 +71,7 @@ public:
     QString name() const     { return tr("2. Team"); }
     QString category() const { return tr("Application"); }
 
-    QWidget *widget();
+    QWidget *createPage(QWidget *parent = 0);
 
 private Q_SLOTS:
     void mailTo(QTreeWidgetItem *item);
