@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -37,9 +37,9 @@ class QWidget;
 
 /**
  * \file icore.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.5.0
- * \date 22 Aug 2010
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 28 Apr 2011
 */
 
 
@@ -56,10 +56,11 @@ class ITheme;
 class ISettings;
 class IMainWindow;
 class ModeManager;
-class CommandLine;
+class ICommandLine;
 class IPatient;
 class IUser;
 class FileManager;
+class IPadTools;
 }
 
 namespace Core {
@@ -69,14 +70,17 @@ class CORE_EXPORT ICore : public QObject
     Q_OBJECT
 
 public:
-    ICore(QObject *parent) : QObject(parent), m_UpdatePreferences(false) {}
-    virtual ~ICore() {}
+    ICore(QObject *parent);
+    virtual ~ICore();
 
     static ICore *instance();
 
     // Some informations
     virtual bool updatePreferences() const {return m_UpdatePreferences;}
 
+    // Alpha dialog
+    virtual bool alphaDialog() const;
+
     // Action manager, ContextManager, ModeManager, FileManager
     virtual ActionManager *actionManager() const = 0;
     virtual ContextManager *contextManager() const = 0;
@@ -89,12 +93,14 @@ public:
     virtual Translators *translators() const = 0;
     virtual ISettings *settings() const = 0;
 
-    virtual CommandLine *commandLine() const = 0;
+    virtual ICommandLine *commandLine() const = 0;
     virtual Utils::UpdateChecker *updateChecker() const = 0;
 
     virtual void setMainWindow(IMainWindow *) = 0;
     virtual IMainWindow *mainWindow() const = 0;
 
+    virtual IPadTools *padTools() const { return 0; } // pad tools are not mandatory for everyone, so not pure virtual
+
     // Patient's datas wrapper
     virtual IPatient *patient() const = 0;
     virtual void setPatient(IPatient *patient) = 0;
