@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -34,7 +34,7 @@
 
 /**
  * \file iuser.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.4.0
  * \date 13 June 2010
 */
@@ -54,23 +54,28 @@ public:
         Id = 0,
         Uuid,           /*!< \brief Unique identifier the each users */
         Validity,       /*!< \brief Validity of this user */
-        Login,          /*!< \brief Crypted login \sa UserGlobal::loginForSQL() */
+        IsVirtual,      /*!< \brief User is virtual ?*/
+        Login64,        /*!< \brief Crypted login \sa UserGlobal::loginForSQL() */
         Password,       /*!< \brief Crypted password \sa UserGlobal::crypt() */
         LastLogin,      /*!< \brief Date of the last correct login */
         Name,           /*!< \brief Name */
         SecondName,     /*!< \brief Second name */
         Firstname,      /*!< \brief Firstname */
         Mail,           /*!< \brief Mail address */
-        Language,       /*!< \brief Language for interface */
+        LanguageISO,    /*!< \brief Language for interface */
         Locker,         /*!< \brief Locker */
-        LanguageIndex,  /*!< \brief Language index from Core::Translators::availableLanguages() */
+        LocaleLanguage, /*!< \brief Language index from Core::Translators::availableLanguages() */  //12
 
         // ORDER CAN CHANGE
+        ClearLogin,
+        ClearPassword,
+        LocaleCodedLanguage,
         PersonalLinkId,
         FullName,
         GenderIndex, TitleIndex, Gender, Title,
-        Adress, Zipcode, City, Country, Tel1, Tel2, Tel3, Fax, PractitionerId,
-        Specialities, Qualifications, Preferences,
+        Adress, Zipcode, City, Country, IsoCountry,
+        Tel1, Tel2, Tel3, Fax, PractitionerId,
+        Specialities, Qualifications, Preferences,  // 31
 
         GenericHeader,
         GenericFooter,
@@ -101,6 +106,7 @@ public:
         MedicalRights,
         ParamedicalRights,
         AdministrativeRights,
+        AgendaRights,
 
         DecryptedLogin,           /*!< \brief Clear human readable login. */
         LoginHistory,             /*!< \brief Full login history of the user. */
@@ -124,13 +130,14 @@ public:
         Delete         = 0x00000400,
         AllRights      = ReadOwn | ReadDelegates | ReadAll | WriteOwn | WriteDelegates | WriteAll | Print | Create | Delete
     };
-    Q_DECLARE_FLAGS(UserRights, UserRight);
+    Q_DECLARE_FLAGS(UserRights, UserRight)
 
     IUser(QObject *parent) : QObject(parent) {}
     virtual ~IUser() {}
 
     virtual void clear() = 0;
     virtual bool has(const int ref) const = 0;
+    virtual bool hasCurrentUser() const = 0;
 
     virtual QVariant value(const int ref) const = 0;
     virtual bool setValue(const int ref, const QVariant &value) = 0;
@@ -138,8 +145,15 @@ public:
     virtual QString toXml() const = 0;
     virtual bool fromXml(const QString &xml) = 0;
 
+    virtual bool saveChanges() = 0;
+
+    virtual QString fullNameOfUser(const QVariant &uid) = 0;
+
     void replaceTokens(QString &stringWillBeModified);
 
+    // Some code easiers
+    QString uuid() const {return value(Uuid).toString();}
+
 Q_SIGNALS:
     void userChanged();
     void userDataChanged(const int ref);
