@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -50,7 +50,8 @@
        |                                    |
        `- .ApplicationName                   `- .ApplicationName
         |                                     |
-        |- config.ini                         |- config.ini
+        |- config.ini                         |- config.ini             == user settings for non-networked apps
+        |- config-network.ini                 |- config-network.ini
         |                                     |
         `- databases                          `- databases
          |                                     |
@@ -123,7 +124,8 @@
      - Core::ISettings::SmallPixmapPath
      - Core::ISettings::MediumPixmapPath
      - Core::ISettings::BigPixmapPath
-     - Core::ISettings::SampleFormsPath
+     - Core::ISettings::CompleteFormsPath
+     - Core::ISettings::SubFormsPath
      - Core::ISettings::DocumentationPath
 */
 
@@ -175,12 +177,12 @@
  * Defines the temporary application path.
 */
 
-/*! \var Core::ISettings::Paths Core::ISettings::FormsPath
- * Defines the users' forms path (FreeMedForms only).
+/*! \var Core::ISettings::Paths Core::ISettings::CompleteFormsPath
+ * Defines the Bundled full patient forms (used only with FreeMedForms).
 */
 
-/*! \var Core::ISettings::Paths Core::ISettings::SampleFormsPath
- * Defines the Bundled forms (used only with FreeMedForms).
+/*! \var Core::ISettings::Paths Core::ISettings::SubFormsPath
+ * Defines the Bundled sub-forms (used only with FreeMedForms).
 */
 
 /*! \var Core::ISettings::Paths Core::ISettings::DocumentationPath
@@ -246,7 +248,6 @@
 
 #include <utils/global.h>
 
-// include Qt headers
 #include <QApplication>
 #include <QMainWindow>
 #include <QDockWidget>
@@ -260,53 +261,54 @@
   \todo Manage user's settings stored into database
 */
 
-namespace SettingsPrivateConstants {
+namespace {
 
-    static const char* const WEBSITE              = "http://www.freemedforms.org/";
+    const char* const WEBSITE              = "http://www.freemedforms.org/";
 
     // BUNDLE RESOURCES  --> located inside the bundle. Location calculated from BundleRootPath
 #ifdef DEBUG
-    static const char* const BUNDLERESOURCE_PATH   = "";                    // resources are located into global_resources paths
+    const char* const BUNDLERESOURCE_PATH   = "";                    // resources are located into global_resources paths
 #else
-    static const char* const BUNDLERESOURCE_PATH  = "/Resources";          // resources are located inside the bundle
+    const char* const BUNDLERESOURCE_PATH  = "/Resources";          // resources are located inside the bundle
 #endif
-    static const char* const READONLYRESOURCES    = "";
-    static const char* const READONLYDATABASE     = "/databases";
-    static const char* const TRANSLATIONS_PATH    = "/translations";
-    static const char* const DEFAULTFORMS         = "/forms";
-    static const char* const DEFAULTTHEME_PATH    = "";
-    static const char* const DEFAULTTHEME_PIXMAP  = "/pixmap";
-    static const char* const DEFAULTTHEME_SPLASH  = "/pixmap/splashscreens";
-    static const char* const USERMANUAL_PATH      = "/doc/%1";
-    static const char* const LINUX_USERMANUAL_PATH  = "/usr/share/doc/%1-doc/html";
+    const char* const READONLYRESOURCES    = "";
+    const char* const READONLYDATABASE     = "/databases";
+    const char* const TRANSLATIONS_PATH    = "/translations";
+    const char* const DEFAULTFORMS         = "/forms";
+    const char* const DEFAULTTHEME_PATH    = "";
+    const char* const DEFAULTTHEME_PIXMAP  = "/pixmap";
+    const char* const DEFAULTTHEME_SPLASH  = "/pixmap/splashscreens";
+    const char* const USERMANUAL_PATH      = "/doc/%1";
+    const char* const LINUX_USERMANUAL_PATH  = "/usr/share/doc/%1-doc/html";
 
     // APPLICATIONS RESOURCES --> located next to the application binary
 #ifdef DEBUG
-    static const char* const MAC_PLUGINSPATH      = "/../../../plugins";
+    const char* const MAC_PLUGINSPATH      = "/../../../plugins";
 #else
-    static const char* const MAC_PLUGINSPATH      = "/../plugins";
+    const char* const MAC_PLUGINSPATH      = "/../plugins";
 #endif
-    static const char* const NONMAC_PLUGINSPATH   = "/plugins";
-    static const char* const ALL_QTPLUGINSPATH    = "/qt";
-    static const char* const MAC_QTFRAMEWORKPATH  = "/../FrameWorks";
-    static const char* const WIN_QTFRAMEWORKPATH  = "";
-    static const char* const UNIX_QTFRAMEWORKPATH = "/../libs";
-    static const char* const MAC_TOBUNDLEROOTPATH = "/../../..";
-    static const char* const WIN_TOBUNDLEROOTPATH = "/..";
-    static const char* const NUX_TOBUNDLEROOTPATH = "/..";
-    static const char* const BSD_TOBUNDLEROOTPATH = "/..";
+    const char* const NONMAC_PLUGINSPATH   = "/plugins";
+    const char* const ALL_QTPLUGINSPATH    = "/qt";
+    const char* const MAC_QTFRAMEWORKPATH  = "/../FrameWorks";
+    const char* const WIN_QTFRAMEWORKPATH  = "";
+    const char* const UNIX_QTFRAMEWORKPATH = "/../libs";
+    const char* const MAC_TOBUNDLEROOTPATH = "/../../..";
+    const char* const WIN_TOBUNDLEROOTPATH = "/..";
+    const char* const NUX_TOBUNDLEROOTPATH = "/..";
+    const char* const BSD_TOBUNDLEROOTPATH = "/..";
 
     // USER WRITABLE RESOURCES  --> located inside/outside the bundle. Location calculated from ResourcesPath (where stands the ini file)
-    static const char* const WRITABLEDATABASE     = "/databases";
+    const char* const WRITABLEDATABASE     = "/databases";
 
     // SETTINGS
-    static const char* const LICENSE_VERSION      = "License/AcceptedVersion";
+    const char* const S_LICENSE_VERSION    = "License/AcceptedVersion";
+    const char* const S_DATABASECONNECTOR  = "Network/Db";
+    const char* const S_DEFAULTFORM        = "Form/Default";
 
 }
 
 using namespace Core;
 using namespace Core::Internal;
-using namespace SettingsPrivateConstants;
 
 
 /**
@@ -314,13 +316,24 @@ using namespace SettingsPrivateConstants;
   All path are calculated by the constructor.\n
   Users' writable resources are located in the dir of the config.ini file.
 */
-SettingsPrivate::SettingsPrivate(QObject *parent, const QString &appName, const QString &fileName)
-        : ISettings(), QSettings(getIniFile(appName, fileName), QSettings::IniFormat,parent)
+SettingsPrivate::SettingsPrivate(QObject *parent, const QString &appName, const QString &fileName) :
+    ISettings(parent),
+    m_NetworkSettings(0),
+    m_UserSettings(0),
+    m_NeedsSync(false)
 {
     setObjectName("SettingsPrivate");
+
+    QString file = getIniFile(appName, fileName);
+    QFileInfo fi(file);
+    QString f = fi.absolutePath() + QDir::separator() + fi.baseName() + "-net." + fi.completeSuffix();
+    m_NetworkSettings = new QSettings(f, QSettings::IniFormat, this);
+    LOG_FOR("Settings", "Using network ini file " + f);
+
+    m_UserSettings = new QSettings(file, QSettings::IniFormat, this);
     QString resourcesPath;
-    QString databasePath;
     QString applicationName;
+
     // if appName like "AppName - debug"  --> use "AppName" only
     if (appName.isEmpty())
         applicationName = qApp->applicationName();
@@ -334,6 +347,13 @@ SettingsPrivate::SettingsPrivate(QObject *parent, const QString &appName, const
     setPath(ApplicationTempPath, QDir::tempPath());
     setPath(SystemTempPath, QDir::tempPath());
     setPath(WebSiteUrl, WEBSITE);
+    setPath(UserDocumentsPath, QDir::homePath() + QDir::separator() + applicationName.remove("-alpha").remove("_alpha").remove("_debug").remove("-debug") + QDir::separator() + "Documents");
+
+    // Create UserDocumentsPath
+    if (!QDir(path(UserDocumentsPath)).exists()) {
+        QDir().mkpath(path(UserDocumentsPath));
+    }
+
 //    if (Utils::isRunningOnLinux())
 //        setPath(FMFPluginsPath, LIBRARY_BASENAME);
 
@@ -341,13 +361,13 @@ SettingsPrivate::SettingsPrivate(QObject *parent, const QString &appName, const
         // DEBUG BUILD
         QString res;
         if (Utils::isRunningOnMac())
-            res = qApp->applicationDirPath() + "/../../../../global_resources";
+            res = qApp->applicationDirPath() + "/../../../../../global_resources";
         else
-            res = qApp->applicationDirPath() + "/../global_resources";
+            res = qApp->applicationDirPath() + "/../../global_resources";
 
         res = QDir::cleanPath(res);
         resourcesPath = res + "/";
-        setPath(ResourcesPath, QFileInfo(QSettings::fileName()).absolutePath());
+        setPath(ResourcesPath, QFileInfo(file).absolutePath());
 
         if (Utils::isRunningOnMac()) {
             setPath(BundleResourcesPath, resourcesPath);
@@ -357,7 +377,7 @@ SettingsPrivate::SettingsPrivate(QObject *parent, const QString &appName, const
     } else {
         // RELEASE BUILD
 #ifdef LINUX_INTEGRATED
-        setPath(BundleResourcesPath, QString("/usr/share/%1").arg(qApp->applicationName()));
+        setPath(BundleResourcesPath, QString("/usr/share/%1").arg(qApp->applicationName().toLower()));
 #else
         if (Utils::isRunningOnMac()) {
             setPath(BundleResourcesPath, qApp->applicationDirPath() + "/../" + QString(BUNDLERESOURCE_PATH));
@@ -366,9 +386,11 @@ SettingsPrivate::SettingsPrivate(QObject *parent, const QString &appName, const
         }
 #endif
         m_FirstTime = value("FirstTimeRunning", true).toBool();
-        setPath(ResourcesPath, QFileInfo(QSettings::fileName()).absolutePath());//QDir::homePath() + "/." + applicationName);//resourcesPath);
+        setPath(ResourcesPath, QFileInfo(file).absolutePath());//QDir::homePath() + "/." + applicationName);//resourcesPath);
     }
 
+    readDatabaseConnector();
+
     if (parent)
         setParent(parent);
     else
@@ -376,7 +398,45 @@ SettingsPrivate::SettingsPrivate(QObject *parent, const QString &appName, const
 }
 
 SettingsPrivate::~SettingsPrivate()
-{}
+{
+    if (m_NetworkSettings) {
+        m_NetworkSettings->sync();
+        delete m_NetworkSettings;
+        m_NetworkSettings = 0;
+    }
+    if (m_UserSettings) {
+//        m_UserSettings->sync();
+        delete m_UserSettings;
+        m_UserSettings = 0;
+    }
+}
+
+void SettingsPrivate::setUserSettings(const QString &content)
+{
+    // create a temp file with the content
+    QString fileName = path(ApplicationTempPath) + QDir::separator() + Utils::Database::createUid() + ".ini";
+    QFile f(fileName);
+    while (f.exists()) {
+        fileName = path(ApplicationTempPath) + QDir::separator() + Utils::Database::createUid() + ".ini";
+        f.setFileName(fileName);
+    }
+
+    // populate the file with the content
+    Utils::saveStringToFile(content, fileName, Utils::Overwrite, Utils::DontWarnUser);
+
+    // change the fileName of the current QSettings
+    if (m_UserSettings) {
+        delete m_UserSettings;
+        m_UserSettings = 0;
+    }
+    m_UserSettings = new QSettings(fileName, QSettings::IniFormat, this);
+    m_NeedsSync = false;
+}
+
+QString SettingsPrivate::userSettings() const
+{
+    return Utils::readTextFile(m_UserSettings->fileName(), Utils::DontWarnUser);
+}
 
 /**
   \fn QSettings *Core::ISettings::getQSettings()
@@ -384,14 +444,47 @@ SettingsPrivate::~SettingsPrivate()
 */
 QSettings *SettingsPrivate::getQSettings()
 {
-    return this;
+    return m_UserSettings;
+}
+
+void SettingsPrivate::beginGroup(const QString &prefix) { m_UserSettings->beginGroup(prefix); m_NeedsSync=true; }
+QStringList SettingsPrivate::childGroups() const { return m_UserSettings->childGroups(); }
+QStringList SettingsPrivate::childKeys() const { return m_UserSettings->childKeys(); }
+bool SettingsPrivate::contains(const QString &key) const { return m_UserSettings->contains(key); }
+void SettingsPrivate::endGroup() { m_UserSettings->endGroup(); m_NeedsSync=true; }
+QString SettingsPrivate::fileName() const { return m_UserSettings->fileName(); }
+QString SettingsPrivate::group() const { return m_UserSettings->group();}
+
+void SettingsPrivate::setValue(const QString &key, const QVariant &value)
+{
+    if (m_UserSettings->value(key, QVariant()) == value)
+        return;
+    m_UserSettings->setValue(key, value);
+    m_NeedsSync=true;
+}
+
+QVariant SettingsPrivate::value(const QString &key, const QVariant &defaultValue) const
+{
+    return m_UserSettings->value(key, defaultValue);
+}
+
+void SettingsPrivate::sync()
+{
+    if (!m_NeedsSync)
+        return;
+    if (m_UserSettings)
+        m_UserSettings->sync();
+    if (m_NetworkSettings)
+        m_NetworkSettings->sync();
+    m_NeedsSync = false;
+    Q_EMIT userSettingsSynchronized();
 }
 
 /**
   \fn void Core::ISettings::setPath(const int type, const QString & absPath)
   \brief defines a path \e absPath with the index \e type refering to the enumarator \e Settings::Paths.
   When setting ApplicationPath, some paths are automatically recalculated : BundleRootPath, QtFrameWorksPath, FMFPlugInsPath, QtPlugInsPath.\n
-  When setting BundleResourcesPath, some paths are automatically recalculated : ReadOnlyDatabasesPath, TranslationsPath, SmallPixmapPath, MediumPixmapPath, BigPixmapPath, SampleFormsPath.\n
+  When setting BundleResourcesPath, some paths are automatically recalculated : ReadOnlyDatabasesPath, TranslationsPath, SmallPixmapPath, MediumPixmapPath, BigPixmapPath, CompleteFormsPath, SubFormsPath.\n
   When setting ResourcesPath, some paths are automatically recalculated : ReadWriteDatabasesPath.\n
 */
 void SettingsPrivate::setPath(const int type, const QString & absPath)
@@ -417,8 +510,7 @@ void SettingsPrivate::setPath(const int type, const QString & absPath)
             m_Enum_Path.insert(ReadWriteDatabasesPath, resourcesPath);
             if (!QDir(resourcesPath).exists())
                 if (!QDir().mkpath(resourcesPath))
-                    Utils::Log::addError("Settings", Trans::ConstantTranslations::tkTr(Trans::Constants::_1_ISNOT_AVAILABLE_CANNOTBE_CREATED).arg(resourcesPath),
-                                         __FILE__, __LINE__);
+                    LOG_ERROR_FOR("Settings", Trans::ConstantTranslations::tkTr(Trans::Constants::_1_ISNOT_AVAILABLE_CANNOTBE_CREATED).arg(resourcesPath));
             break;
         }
         case BundleResourcesPath :
@@ -433,7 +525,9 @@ void SettingsPrivate::setPath(const int type, const QString & absPath)
             m_Enum_Path.insert(SmallPixmapPath, bundlePath + DEFAULTTHEME_PIXMAP + "/16x16/");
             m_Enum_Path.insert(MediumPixmapPath, bundlePath + DEFAULTTHEME_PIXMAP + "/32x32/");
             m_Enum_Path.insert(BigPixmapPath, bundlePath + DEFAULTTHEME_PIXMAP + "/64x64/");
-            m_Enum_Path.insert(SampleFormsPath, bundlePath + DEFAULTFORMS);
+            m_Enum_Path.insert(SvgPixmapPath, bundlePath + DEFAULTTHEME_PIXMAP + "/svg/");
+            m_Enum_Path.insert(SubFormsPath, bundlePath + DEFAULTFORMS + "/subforms");
+            m_Enum_Path.insert(CompleteFormsPath, bundlePath + DEFAULTFORMS + "/completeforms");
             QString appname = qApp->applicationName().toLower();
             if (qApp->applicationName().contains(" ")) {
                 appname = appname.left(appname.indexOf(" "));
@@ -510,24 +604,51 @@ QString SettingsPrivate::path(const int type) const
 }
 
 /**
-  \fn bool Core::ISettings::firstTimeRunning() const
+  \fn bool Core::ISettings::firstTimeRunning(const QString &subProcess) const
   \brief Return true if the application runs for the first time.
-  \sa noMoreFirstTimeRunning()
+  \sa noMoreFirstTimeRunning(const QString &subProcess)
 */
-bool SettingsPrivate::firstTimeRunning() const
+bool SettingsPrivate::firstTimeRunning(const QString &subProcess) const
 {
-    return value("FirstTimeRunning", true).toBool();
+    if (subProcess.isEmpty())
+        return m_NetworkSettings->value("FirstTimeRunning", true).toBool();
+    return m_UserSettings->value("FirstTimeRunning/" + subProcess, true).toBool();
 }
 
 /**
-  \fn void Core::ISettings::noMoreFirstTimeRunning()
+  \fn void Core::ISettings::noMoreFirstTimeRunning(const QString &subProcess)
   \brief Set the first time running of this application to false.
-  \sa firstTimeRunning()
+  \sa firstTimeRunning(const QString &subProcess)
 */
-void SettingsPrivate::noMoreFirstTimeRunning()
+void SettingsPrivate::noMoreFirstTimeRunning(const QString &subProcess)
 {
-    setValue("FirstTimeRunning", false);
-    m_FirstTime = false;
+    if (subProcess.isEmpty()) {
+        m_NetworkSettings->setValue("FirstTimeRunning", false);
+        m_NetworkSettings->sync();
+        m_FirstTime = false;
+    } else {
+        m_UserSettings->setValue("FirstTimeRunning/" + subProcess, false);
+        m_NeedsSync = true;
+        Q_EMIT userSettingsSynchronized();
+    }
+}
+
+/**
+  \fn void Core::ISettings::setFirstTimeRunning(const bool state, const QString &subProcess)
+  \brief Set the first time running of this application to false.
+  \sa firstTimeRunning(const QString &subProcess)
+*/
+void SettingsPrivate::setFirstTimeRunning(const bool state, const QString &subProcess)
+{
+    if (subProcess.isEmpty()) {
+        m_NetworkSettings->setValue("FirstTimeRunning", state);
+        m_NetworkSettings->sync();
+        m_FirstTime = false;
+    } else {
+        m_UserSettings->setValue("FirstTimeRunning/" + subProcess, state);
+        m_NeedsSync = true;
+        Q_EMIT userSettingsSynchronized();
+    }
 }
 
 /**
@@ -535,7 +656,7 @@ void SettingsPrivate::noMoreFirstTimeRunning()
 */
 QString SettingsPrivate::licenseApprovedApplicationNumber() const
 {
-    return value(LICENSE_VERSION).toString();
+    return m_NetworkSettings->value(S_LICENSE_VERSION).toString();
 }
 
 /**
@@ -543,7 +664,25 @@ QString SettingsPrivate::licenseApprovedApplicationNumber() const
 */
 void SettingsPrivate::setLicenseApprovedApplicationNumber(const QString &version)
 {
-    setValue(LICENSE_VERSION, version);
+    m_NetworkSettings->setValue(S_LICENSE_VERSION, version);
+}
+
+/**
+  \fn void Core::ISettings::setDefaultForm(const QString &formUid)
+  Store the default form to use for patient files. Only used by the Application General Configurator.
+*/
+void SettingsPrivate::setDefaultForm(const QString &formUid)
+{
+    m_NetworkSettings->setValue(S_DEFAULTFORM, formUid);
+}
+
+/**
+  \fn void Core::ISettings::defaultForm() const
+  Return the default form to use for patient files. Only used by the Application General Configurator.
+*/
+QString SettingsPrivate::defaultForm() const
+{
+    return m_NetworkSettings->value(S_DEFAULTFORM).toString();
 }
 
 /**
@@ -565,6 +704,9 @@ QString SettingsPrivate::getIniFile(const QString & appName, const QString & fil
             tmpAppName = tmpAppName.left(tmpAppName.indexOf(" "));
     }
     tmpAppName.prepend(".");
+    if (Utils::isAlpha()) {
+        tmpAppName.append("_alpha");
+    }
 
     if (fileName.isEmpty())
         tmpFileName = "config.ini";
@@ -578,7 +720,7 @@ QString SettingsPrivate::getIniFile(const QString & appName, const QString & fil
     if (index != -1) {
         QString iniFileName = list[index];
         iniFileName = iniFileName.mid(iniFileName.indexOf("=") + 1);
-        Utils::Log::addMessage("Settings", tr("Passing command line ini file : %1").arg(iniFileName));
+        LOG_FOR("Settings", tr("Passing command line ini file : %1").arg(iniFileName));
 
         if (QDir::isRelativePath(iniFileName))
             iniFileName.prepend(qApp->applicationDirPath() + QDir::separator());
@@ -587,21 +729,20 @@ QString SettingsPrivate::getIniFile(const QString & appName, const QString & fil
         QFileInfo info(iniFileName);
         if (info.exists() && info.isReadable()) {
             if (info.isWritable()) {
-                Utils::Log::addMessage("Settings", tr("Using ini file %1.").arg(iniFileName));
+                LOG_FOR("Settings", tr("Using ini file %1.").arg(iniFileName));
                 return iniFileName;
             }
             else
-                Utils::Log::addError("Settings", tr("Ini file %1 is not writable. Can not use it.").arg(iniFileName),
-                                     __FILE__, __LINE__);
+                LOG_ERROR_FOR("Settings", tr("Ini file %1 is not writable. Can not use it.").arg(iniFileName));
         } else {
             // can we create and access to ini file ?
             QFile file(iniFileName);
             if (file.open(QIODevice::ReadWrite | QIODevice::Text)) {
-                Utils::Log::addMessage("Settings", tr("Using ini file %1").arg(iniFileName));
+                LOG_FOR("Settings", tr("Using ini file %1").arg(iniFileName));
                 return iniFileName;
             }
             else
-                Utils::Log::addMessage("Settings", tr("WARNING : Ini file %1 can not be used.").arg(iniFileName));
+                LOG_FOR("Settings", tr("WARNING : Ini file %1 can not be used.").arg(iniFileName));
         }
     }
 
@@ -617,21 +758,20 @@ QString SettingsPrivate::getIniFile(const QString & appName, const QString & fil
             QFileInfo info(content);
             if (info.exists() && info.isReadable()) {
                 if (info.isWritable()) {
-                    Utils::Log::addMessage("Settings", tr("Using ini file %1.").arg(content));
+                    LOG_FOR("Settings", tr("Using ini file %1.").arg(content));
                     return content;
                 }
                 else
-                    Utils::Log::addError("Settings", tr("Ini file %1 is not writable. Can not use it.").arg(content),
-                                         __FILE__, __LINE__);
+                    LOG_ERROR_FOR("Settings", tr("Ini file %1 is not writable. Can not use it.").arg(content));
             } else {
                 // can we create and access to ini file ?
                 QFile file(content);
                 if (file.open(QIODevice::ReadWrite | QIODevice::Text)) {
-                    Utils::Log::addMessage("Settings", tr("Using ini file %1").arg(content));
+                    LOG_FOR("Settings", tr("Using ini file %1").arg(content));
                     return content;
                 }
                 else
-                    Utils::Log::addMessage("Settings", tr("WARNING : Ini file %1 can not be used.").arg(content));
+                    LOG_FOR("Settings", tr("WARNING : Ini file %1 can not be used.").arg(content));
             }
         }
     }
@@ -659,19 +799,18 @@ QString SettingsPrivate::getIniFile(const QString & appName, const QString & fil
 
     // Now use the $HOME path
     iniFile = QString("%1/%2/%3").arg(QDir::homePath(), tmpAppName, tmpFileName);
-    Utils::Log::addMessage("Settings", tr("Trying ini file %1").arg(iniFile));
+    LOG_FOR("Settings", tr("Trying ini file %1").arg(iniFile));
     QDir dir(QFileInfo(iniFile).absolutePath());
 
     if (!dir.exists()) {
         dir.cdUp();
         if (!dir.mkdir(tmpAppName)) {
-            Utils::Log::addError("Settings" , tr("Unable to create dir : %1, no Ini File can be used.").arg(dir.absolutePath() + QDir::separator() + tmpAppName),
-                                 __FILE__, __LINE__);
+            LOG_ERROR_FOR("Settings" , tr("Unable to create dir : %1, no Ini File can be used.").arg(dir.absolutePath() + QDir::separator() + tmpAppName));
             return QString::null;
         }
     }
 
-    Utils::Log::addMessage("Settings", tr("Using ini file %1").arg(iniFile));
+    LOG_FOR("Settings", tr("Using ini file %1").arg(iniFile));
     return iniFile;
 }
 
@@ -679,20 +818,35 @@ QString SettingsPrivate::getIniFile(const QString & appName, const QString & fil
   \fn void Core::ISettings::restoreState(QMainWindow * window, const QString & prefix)
   \brief Main windows restore state. \e prefix can be used if you store multiple main window in the same settings
 */
-void SettingsPrivate::restoreState(QMainWindow * window, const QString & prefix)
+#include <QDesktopWidget>
+void SettingsPrivate::restoreState(QMainWindow *window, const QString & prefix)
 {
     if (!window)
         return;
     QString keyGeo = prefix + "MainWindow/Geometry";
     QString keyState = prefix + "MainWindow/State";
     if (value(keyGeo).toByteArray().isEmpty()) {
-        window->setGeometry(100, 100, 600, 400);
-        Utils::centerWidget(window);
+        int height = qApp->desktop()->height() * 0.75;
+        int width = qApp->desktop()->width() * 0.75;
+        // screen is 4/3 ?
+        double screenRatio = (double)width/(double)height;
+        QSize ratio;
+        if (screenRatio < 1.5) {
+            ratio = QSize(4,3);
+        } else {
+            ratio = QSize(16, 9);
+        }
+        QSize result(width, height);
+        ratio.scale(result, Qt::KeepAspectRatio);
+        QRect appScreen(QPoint(0,0), ratio);
+        QRect rect = qApp->desktop()->rect();
+        appScreen.moveCenter(rect.center());
+        window->setGeometry(appScreen);
     } else {
         window->restoreGeometry(value(keyGeo).toByteArray());
         window->restoreState(value(keyState).toByteArray());
         // get all settings key starting with prefix+"/Dock"
-        QStringList k = this->allKeys().filter(QRegExp(QString(prefix + "Dock/"), Qt::CaseSensitive, QRegExp::Wildcard));
+        QStringList k = m_UserSettings->allKeys().filter(QRegExp(QString(prefix + "Dock/"), Qt::CaseSensitive, QRegExp::Wildcard));
         QWidget *w = 0;
         foreach(const QString &s, k) {
             w = window->findChild<QDockWidget*>(s.mid(s.indexOf("Dock/")+5));
@@ -753,6 +907,7 @@ QTreeWidget* SettingsPrivate::getTreeWidget(QWidget *parent) const
 
     // add columns
     tree->setColumnCount(2);
+    tree->setHeaderLabels(QStringList() << tr("Name") << tr("Value"));
     QFont bold;
     bold.setBold(true);
 
@@ -775,10 +930,7 @@ QTreeWidget* SettingsPrivate::getTreeWidget(QWidget *parent) const
         new QTreeWidgetItem(compilItem, QStringList() << tr("Compile mode") << Trans::ConstantTranslations::tkTr(Trans::Constants::BUILD_DEBUG));
     else
         new QTreeWidgetItem(compilItem, QStringList() << tr("Compile mode") << Trans::ConstantTranslations::tkTr(Trans::Constants::BUILD_RELEASE));
-    if (Utils::isFullApplication())
-        new QTreeWidgetItem(compilItem, QStringList() << tr("Application source") << Trans::ConstantTranslations::tkTr(Trans::Constants::BUILD_FULLAPP));
-    else
-        new QTreeWidgetItem(compilItem, QStringList() << tr("Application source") << Trans::ConstantTranslations::tkTr(Trans::Constants::BUILD_SVNAPP));
+    new QTreeWidgetItem(compilItem, QStringList() << tr("SVN version") << QString(SVN_VERSION));
 
 
     // add paths
@@ -799,8 +951,8 @@ QTreeWidget* SettingsPrivate::getTreeWidget(QWidget *parent) const
     paths.insert(tr("BigPixmapPath"), path(BigPixmapPath));
     paths.insert(tr("SystemTempPath"), path(SystemTempPath));
     paths.insert(tr("ApplicationTempPath"), path(ApplicationTempPath));
-    paths.insert(tr("FormsPath"), path(FormsPath));
-    paths.insert(tr("SampleFormsPath"), path(SampleFormsPath));
+    paths.insert(tr("CompleteFormsPath"), path(CompleteFormsPath));
+    paths.insert(tr("SubFormsPath"), path(SubFormsPath));
     paths.insert(tr("DocumentationPath"), path(DocumentationPath));
 
     QTreeWidgetItem * absPathsItem = new QTreeWidgetItem(tree, QStringList() << tr("Absolute Paths"));
@@ -811,8 +963,7 @@ QTreeWidget* SettingsPrivate::getTreeWidget(QWidget *parent) const
     relPathsItem->setFont(0,bold);
     new QTreeWidgetItem(relPathsItem, QStringList() << tr("Using Ini File") << appDir.relativeFilePath(QFileInfo(fileName()).absoluteFilePath()));
 
-    foreach(const QString & p, paths.keys())
-    {
+    foreach(const QString & p, paths.keys()) {
         new QTreeWidgetItem(relPathsItem, QStringList() << p << appDir.relativeFilePath(QFileInfo(paths[p]).absoluteFilePath()));
         new QTreeWidgetItem(absPathsItem, QStringList() << p << paths[p]);
     }
@@ -829,7 +980,7 @@ QTreeWidget* SettingsPrivate::getTreeWidget(QWidget *parent) const
     QTreeWidgetItem * orphan = new QTreeWidgetItem(settingsItem, QStringList() << tr("Orphan settings"));
     orphan->setFont(0,bold);
     QTreeWidgetItem * group = 0;
-    QStringList list = allKeys();
+    QStringList list = m_UserSettings->allKeys();
     qSort(list);
     foreach(const QString & k, list) {
         if (k.contains("/")) {
@@ -855,10 +1006,7 @@ QTreeWidget* SettingsPrivate::getTreeWidget(QWidget *parent) const
     return tree;
 }
 
-/**
- \fn QString Core::ISettings::toString() const
- \brief For debugging purpose.
-*/
+/** \brief For debugging purpose. */
 QString SettingsPrivate::toString() const
 {
     QString tmp = "\n\n";
@@ -876,10 +1024,7 @@ QString SettingsPrivate::toString() const
         tmp += tr("Actual build : Debug\n");
     else
         tmp += tr("Actual build : Release\n");
-    if (Utils::isFullApplication())
-        tmp += tr("Actual build") + " : " + tr("Full Application Build\n");
-    else
-        tmp += tr("Actual build") + " : " + tr("Svn Build\n");
+    tmp += tr("SVN version : %1\n").arg(SVN_VERSION);
     tmp += tr("Application path : %1\n").arg(qApp->applicationDirPath());
     tmp += QString("Ini File Name\t%2").arg(fileName()) + "\n";
     tmp += tr("Using Ini File") + "\t" + fileName() + "\n";
@@ -913,18 +1058,45 @@ QString SettingsPrivate::toString() const
     paths.insert(tr("BigPixmapPath"), path(BigPixmapPath));
     paths.insert(tr("SystemTempPath"), path(SystemTempPath));
     paths.insert(tr("ApplicationTempPath"), path(ApplicationTempPath));
-    paths.insert(tr("FormsPath"), path(FormsPath));
-    paths.insert(tr("SampleFormsPath"), path(SampleFormsPath));
+    paths.insert(tr("FormsPath"), path(CompleteFormsPath));
+    paths.insert(tr("SampleFormsPath"), path(SubFormsPath));
     paths.insert(tr("DocumentationPath"), path(DocumentationPath));
     paths.insert(tr("WebSiteUrl"), path(WebSiteUrl));
     foreach(const QString & p, paths.keys())
         tmp += p + "\t" + paths[p] + "\n";
 
     // add all values of the inifile
-    foreach(QString k, allKeys())
+    foreach(QString k, m_UserSettings->allKeys())
         tmp += QString("%1\t%2\n").arg(k, value(k).toString());
     tmp += "\n\n";
 
     return tmp;
 }
 
+/** Returns all server connection's params */
+Utils::DatabaseConnector SettingsPrivate::databaseConnector() const
+{
+    return m_DbConnector;
+}
+
+/** Define all server connection's params. Params are automatically saved into the settings file. */
+void SettingsPrivate::setDatabaseConnector(Utils::DatabaseConnector &dbConnector)
+{
+    m_DbConnector = dbConnector;
+    m_DbConnector.setAbsPathToReadOnlySqliteDatabase(path(Core::ISettings::ReadOnlyDatabasesPath));
+    m_DbConnector.setAbsPathToReadWriteSqliteDatabase(path(Core::ISettings::ReadWriteDatabasesPath));
+    writeDatabaseConnector();
+}
+
+void SettingsPrivate::readDatabaseConnector()
+{
+    m_DbConnector.fromSettings(m_NetworkSettings->value(S_DATABASECONNECTOR).toString());
+    m_DbConnector.setAbsPathToReadOnlySqliteDatabase(path(Core::ISettings::ReadOnlyDatabasesPath));
+    m_DbConnector.setAbsPathToReadWriteSqliteDatabase(path(Core::ISettings::ReadWriteDatabasesPath));
+}
+
+void SettingsPrivate::writeDatabaseConnector()
+{
+    m_NetworkSettings->setValue(S_DATABASECONNECTOR, m_DbConnector.forSettings());
+    m_NetworkSettings->sync();
+}
