@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -27,30 +27,34 @@
 #ifndef DRUGSBASE_CONSTANTS_H
 #define DRUGSBASE_CONSTANTS_H
 
+#include <drugsbaseplugin/constants_databaseschema.h>
+
 #include <QFlags>
 #include <QHash>
 #include <QStringList>
 
 /**
  * \file constants.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.4.0
- * \date 02 Mar 2010
-*/
-
-/**
- \brief Some constants for Drugs management
- \ingroup freediams drugswidget
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 02 Mar 2011
 */
 
 namespace DrugsDB {
+
+    /** \brief Some constants for Drugs management */
+
 namespace Constants {
 
     // SETTINGS
     const char * const S_USERRECORDEDFORMS       = "DrugsWidget/userRecordedForms";
     const char * const S_SHOWICONSINPRESCRIPTION = "DrugsWidget/view/ShowIconsInPrescription";      /*!< \brief Key for settings. */
     const char * const S_HIDELABORATORY          = "DrugsWidget/print/drug/hideLaboratory";    /*!< \brief Key for settings. */
-    const char * const S_LEVELOFWARNING          = "DrugsWidget/levelOfWarning";               /*!< \brief Key for settings. */
+
+    const char * const S_LEVELOFWARNING_STATICALERT = "DrugsWidget/levelOfWarning";               /*!< \brief Key for settings. */
+    const char * const S_USEDYNAMICALERTS           = "DrugsWidget/dynamicAlerts";
+    const char * const S_LEVELOFWARNING_DYNAMICALERT= "DrugsWidget/dynamicAlertsMinimalLevel";
+
 
     const char * const  S_USERHEADER             = "DrugsWidget/user/Header";                  /*!< \brief Key for settings. */
     const char * const  S_USERFOOTER             = "DrugsWidget/user/Footer";                  /*!< \brief Key for settings. */
@@ -111,6 +115,9 @@ namespace Constants {
 
     const char * const S_PROTOCOL_DEFAULT_SCHEMA        ="Protocols/DefaultSchema";
 
+    const char * const S_ACTIVATED_INTERACTION_ENGINES  ="DrugsWidget/Engines/Activated";
+
+
     // ICONS
     const char * const  I_SEARCHCOMMERCIAL =  "pill.png";              /*!< \brief Themed icon name for Commercial search. */
     const char * const  I_SEARCHMOLS =        "molecule.png";          /*!< \brief Themed icon name for Molecules search. */
@@ -122,9 +129,18 @@ namespace Constants {
     const char * const  I_PROTOCOL_SAVE =              "protocol_save.png";
     const char * const  I_PROTOCOL_TESTONLY =          "protocol_testonly.png";
 
+    const char * const  I_DRUGENGINE = "drugengines.png";
+    const char * const  I_DRUGDRUGINTERACTIONENGINE = "drugengine_ddi.png";
+    const char * const  I_PIMENGINE = "pimengine.png";
+    const char * const  I_ALLERGYENGINE = "drugengines_allergies.png";
+
+    const char * const  I_DRUGALERT_ACCEPT = "drugalert_accept.png";
+    const char * const  I_DRUGALERT_OVERRIDE = "drugalert_override.png";
+    const char * const  I_DRUGREPORT = "drugreport.png";
+
     // INTERACTIONS ICONS
     const char * const  INTERACTION_ICONCRITICAL =         "critical.png";      /*!< \brief Themed icon name for Interactions logo. */
-    const char * const  INTERACTION_ICONDECONSEILLEE =     "deconseille.png";   /*!< \brief Themed icon name for Interactions logo. */
+    const char * const  INTERACTION_ICONDECONSEILLEE =     "unadvised.png";   /*!< \brief Themed icon name for Interactions logo. */
     const char * const  INTERACTION_ICONTAKEINTOACCOUNT =  "warning.png";       /*!< \brief Themed icon name for Interactions logo. */
     const char * const  INTERACTION_ICONPRECAUTION =       "info.png";          /*!< \brief Themed icon name for Interactions logo. */
     const char * const  INTERACTION_ICONINFORMATION =      "information.png";          /*!< \brief Themed icon name for Interactions logo. */
@@ -234,119 +250,53 @@ namespace Constants {
                               ;
 
 
-    // DATABASE
-    const char * const DB_DRUGS_NAME     = "drugs";            /*!< \brief Drugs database connection name. */
-    const char * const DB_IAM_NAME       = "iam";            /*!< \brief Drugs database connection name. */
-    const char * const DB_DEFAULT_DRUGS_FILENAME = "drugs-fr_FR.db";         /*!< \brief Drug database file name (for SQLite). */
-    const char * const DB_IAM_FILENAME   = "iam.db";         /*!< \brief Drug database file name (for SQLite). */
-    const char * const DB_DEFAULT_IDENTIFIANT  = "FR_AFSSAPS";
+    // Translations
+    const char * const  DRUGSBASE_TR_CONTEXT = "mfDrugsConstants";
+    const char * const  NATURE_OF_RISK = QT_TRANSLATE_NOOP("mfDrugsConstants", "Nature of risk");
+    const char * const  MANAGEMENT = QT_TRANSLATE_NOOP("mfDrugsConstants", "Management");
+    const char * const  DDI_TEXT = QT_TRANSLATE_NOOP("mfDrugsConstants", "Drug-drug interactions");
 
-    //--------------------------------------------------------------------------------------------------------
-    //------------------------------------ Enums for Database Management -------------------------------------
-    //--------------------------------------------------------------------------------------------------------
-    /** \brief Represents the tables index of drugs database */
-    enum Tables
-    {
-        Table_DRUGS=0, Table_COMPO, Table_PACKAGING, Table_LK_MOL_ATC, Table_INFORMATION,
-        Table_INTERACTIONS, Table_INTERACTION_KNOWLEDGE, Table_ATC, Table_IAM_TREE, Table_SOURCES, Table_DOSAGE,
-        Table_SEARCHENGINES, Table_DRUG_ROUTES, Table_ROUTES,
-        Table_MaxParam
+     /*: This is the short name of the Drug-drug interactions engine. */
+    const char * const  DDI_SHORT_TEXT = QT_TRANSLATE_NOOP("mfDrugsConstants", "DDI");
+
+    const char * const  PIMENGINE_TEXT = QT_TRANSLATE_NOOP("mfDrugsConstants", "Potentially inappropriate medications");
+
+    /*: This is the short name of the Potentially inappropriate medications engine. */
+    const char * const  PIMENGINE_SHORT_TEXT = QT_TRANSLATE_NOOP("mfDrugsConstants", "PIM");
+    const char * const  PIM_TEXT = QT_TRANSLATE_NOOP("mfDrugsConstants", "Potentially inappropriate medications");
+
+
+    const char * const  ALLERGYENGINE_TEXT = QT_TRANSLATE_NOOP("mfDrugsConstants", "Allergy / Intolerances to medications");
+
+    /*: This is the short name of the Potentially inappropriate medications engine. */
+    const char * const  ALLERGY_TEXT = QT_TRANSLATE_NOOP("mfDrugsConstants", "Allergy");
+
+    // Some usefull enums
+    enum LevelOfInteractionWarnings {
+        MaximumLevelOfWarning = 0,
+        ModerateLevelOfWarning,
+        MinimumLevelOfWarning
     };
 
-    /** \brief Represents the fields index of drugs database table CIS */
-    enum DRUGSfields
-    { DRUGS_UID = 0, DRUGS_NAME, DRUGS_FORM, DRUGS_ROUTE, DRUGS_ATC, DRUGS_STRENGTH, DRUGS_TYPE_MP,
-      DRUGS_AUTHORIZATION, DRUGS_MARKET, DRUGS_LINK_SPC,
-      DRUGS_MaxParam
-    };
-
-    /** \brief Represents the fields index of drugs database table CIP */
-    enum PACKAGINGfields // table CIS_CIP
-    { PACK_DRUG_UID = 0, PACK_PACK_UID, PACK_LABEL, PACK_STATUS, PACK_MARKET,
-      PACK_DATE, PACK_OPTION_CODE,
-      PACK_MaxParam
-    };
-
-    /** \brief Represents the fields index of drugs database table COMPO */
-    enum COMPOSITIONfields
-    { COMPO_UID = 0,
-      COMPO_MOL_FORM,
-      COMPO_MOL_CODE, COMPO_MOL_NAME,
-      COMPO_MOL_ATC,
-      COMPO_DOSAGE, COMPO_REF_DOSAGE,
-      COMPO_NATURE, COMPO_LK_NATURE,
-      COMPO_MaxParam, COMPO_IAM_DENOMINATION, COMPO_IAM_CLASS_DENOMINATION, COMPO_VeryMaxParam
-    };
-
-    enum LINKfields {
-        LK_MOLECULECODE = 0, LK_ATC_ID, LK_MaxParam
-    };
-
-    enum INFOfields
-    { INFO_VERSION = 0, INFO_NAME, INFO_IDENTIFIANT, INFO_COMPAT_VERSION, INFO_PROVIDER, INFO_WEBLINK,
-      INFO_COMPLEMENTARY_WWW,
-      INFO_AUTHOR, INFO_LICENSE, INFO_LICENSE_TERMS, INFO_DATE, INFO_DRUG_UID_NAME, INFO_PACK_MAIN_CODE_NAME,
-      INFO_ATC, INFO_INTERACTIONS, INFO_MOLLINKCOMPLETION, INFO_AUTHOR_COMMENTS, INFO_LANGUAGE_COUNTRY, INFO_DRUGS_NAME_CONSTRUCTOR,
-      INFO_MaxParam
-    };
-
-    /** \brief Represents the fields index of drugs database table IAM_DENOMINATION */
-    enum INTERACTIONSfields
-    { IA_ID = 0, IA_ATC1, IA_ATC2, IA_IAK_ID,
-      IA_MaxParam
-    };
-
-    /** \brief Represents the fields index of drugs database table IAM_IMPORT */
-    enum INTERACTION_KNOWLEDGEfields
-    { IAK_ID = 0, IAK_TYPE, IAK_RISK_FR, IAK_MANAGEMENT_FR, IAK_RISK_EN, IAK_MANAGEMENT_EN,
-      IAK_REFERENCES_LINK,
-      IAK_MaxParam
-    };
-
-    /** \brief Represents the fields index of drugs database table ATC */
-    enum ATCfields
-    { ATC_ID = 0, ATC_CODE, ATC_EN, ATC_FR, ATC_DE,
-      ATC_MaxParam
-    };
-
-    /** \brief Represents the fields index of drugs database table ATC */
-    enum IAM_TREEfields
-    { TREE_ID_CLASS = 0, TREE_ID_ATC, TREE_SOURCE_LINK,
-      TREE_MaxParam
-    };
-
-    enum SOURCESfields {
-        SOURCES_ID = 0, SOURCES_SOURCE_LINK, SOURCES_TYPE, SOURCES_LINK,
-        SOURCES_TEXTUAL_REFERENCE, SOURCES_ABSTRACT, SOURCES_EXPLANATION,
-        SOURCES_MaxParam
-    };
-
-    enum SEARCHENGINESfields {
-        SEARCHENGINE_ID, SEARCHENGINE_LABEL, SEARCHENGINE_URL
-    };
-
-    enum ROUTESFields {
-        ROUTES_ID = 0, ROUTES_FR, ROUTES_EN, ROUTES_DE
-    };
-
-    enum DRUGSROUTESFields {
-        DRUG_ROUTES_UID, DRUG_ROUTES_ROUTE_ID
-    };
+    // Drugs engines uid
+    const char * const  DDI_ENGINE_UID = "ddiEngine";
+    const char * const  PIM_ENGINE_UID = "pimEngine";
+    const char * const  ALLERGY_ENGINE_UID = "allergyEngine";
 
     //--------------------------------------------------------------------------------------------------------
     //------------------------------------- Enums for Models Management --------------------------------------
     //--------------------------------------------------------------------------------------------------------
-/**
- \brief Used by DrugsModel for column representation.
- \ingroup freediams
- \ingroup drugswidget
- */
+
+    /** \brief Used by DrugsModel for column representation. */
+
 namespace Drug
 {
     enum Drug
     {
         Id = 1000,
-        UID,
+        UIDs,
+        OldUid,
+        DrugId,
         Pack_UID,
         Denomination,
         Form,
@@ -357,7 +307,8 @@ namespace Drug
         CodeMoleculesList,
         AllInnsKnown,
         Inns,                    // names
-        InnsATCcodes,
+        InnCodes,                // all INN in ATC format (classes not included)
+        InnsATCcodes,            // all INN in ATC format (classes are included)
         InnClasses,              // names
         MainInnCode,             // -1 if no INN known or more than one INN
         MainInnName,             // -1 if no INN known or more than one INN
@@ -366,7 +317,7 @@ namespace Drug
         Administration,
         Interacts,
         OwnInteractionsSynthesis,
-        MaximumLevelOfInteraction,
+//        MaximumLevelOfInteraction,
         CompositionString,
         InnCompositionString,    // inn dose form ; inn dose form...
         AvailableForms,
@@ -380,11 +331,7 @@ namespace Drug
 
 }  // End namespace Drugs::Constants::Drug
 
-/**
- \brief Used by DrugsModel for column representation.
- \ingroup freediams
- \ingroup drugswidget
- */
+/** \brief Used by DrugsModel for column representation. */
 namespace Prescription
 {
     enum Prescription
@@ -399,7 +346,8 @@ namespace Prescription
         IntakesScheme,
         IntakesUsesFromTo,
         IntakesFullString,
-        Route,
+        Route,            // Textual translated route
+        RouteId,          // Route Id from drugs database
         DurationFrom,
         DurationTo,
         DurationScheme,
@@ -422,11 +370,7 @@ namespace Prescription
 
 }  // End namespace Drugs::Constants::Prescription
 
-/**
- \brief Used by DrugsModel for column representation.
- \ingroup freediams
- \ingroup drugswidget
-*/
+/** \brief Used by DrugsModel for column representation. */
 namespace Interaction
 {
     enum InteractionModelFields
@@ -434,51 +378,26 @@ namespace Interaction
         Id = 2000,
         Icon,
         Pixmap,
-        MediumPixmap,
         ToolTip,
         FullSynthesis,
         MaxParam
     };
 
-    enum TypeOfIAM
-    {
-        noIAM            = 0x0000,
-        Unknown          = 0x0001,
-        Information      = 0x0002,
-        InnDuplication   = 0x0004,
-        Precaution       = 0x0010,
-        APrendreEnCompte = 0x0020,
-        P450             = 0x0100,
-        GPG              = 0x0200,
-        Deconseille      = 0x1000,
-        ContreIndication = 0x8000
-    };
-    Q_DECLARE_FLAGS( TypesOfIAM, TypeOfIAM );
-
 }  // End namespace Drugs::Constants::Interaction
-Q_DECLARE_OPERATORS_FOR_FLAGS( Interaction::TypesOfIAM )
 
 }  // End namespace DrugsDB::Constants
 }  // End namespace DrugsDB
 
 
-/**
- \brief Some constants.
- \ingroup freediams
- \ingroup drugswidget
-*/
 namespace Dosages {
+
+    /**  \brief Some constants. */
 namespace Constants {
     const char * const DB_DOSAGES_NAME = "dosages";          /*!< \brief Dosage database connection name. */
     const char * const DB_DOSAGES_FILENAME = "dosages.db";   /*!< \brief Dosage database name (SQLite). */
     const char * const DB_DOSAGES_TABLE_NAME = "DOSAGE";              /*!< \brief Table name for dosages. */
 
-/**
- \brief Used by mfDosageModel for column representation.
- \ingroup freediams
- \ingroup drugswidget
-*/
-    /** \brief Used by mfDosageModel for column representation. */
+    /** \brief Used by DosageModel for column representation. */
     enum Dosage
     {
         Id = 0,                 /*!< \brief Identifiant du dosage. integer. */
@@ -496,7 +415,7 @@ namespace Constants {
         IntakesScheme,           /*!< \brief Forme sélectionnée */
         IntakesIntervalOfTime,  /*!< \brief temps entre chaque prise --> int */
         IntakesIntervalScheme,  /*!< \brief schéma de temps --> int cf enum */
-        Route,
+        RouteId,
 
         DurationFrom,           /*!< \brief espacement prises  --> double */
         DurationTo,             /*!< \brief espacement prises  --> double */
@@ -534,6 +453,7 @@ namespace Constants {
         CreationDate,           /*!< \brief Date création      --> date */
         ModificationDate,       /*!< \brief Date modification  --> date */
         Transmitted,            /*!< \brief Sera utilisé pour récupérer via internet les dosages référencés en local. date */
+        Route,                  /*!< \brief Outside SQL */
         MaxParam                /*!< \brief Nombre maximum de colonnes du modèle (et de la table SQL) */
     };
 
