@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -32,12 +32,17 @@
 
 /**
  * \file drugsbaseplugin.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.2.1
- * \date 25 Oct 2009
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 25 Sept 2011
 */
 
 namespace DrugsDB {
+namespace Internal {
+class DrugDrugInteractionEngine;
+class PimEngine;
+class DrugAllergyEngine;
+}
 
 class DrugsBasePlugin : public ExtensionSystem::IPlugin
 {
@@ -48,6 +53,11 @@ public:
 
     bool initialize(const QStringList &arguments, QString *errorString);
     void extensionsInitialized();
+
+private:
+    DrugsDB::Internal::DrugDrugInteractionEngine *m_DDIEngine;
+    DrugsDB::Internal::PimEngine *m_PimEngine;
+    DrugsDB::Internal::DrugAllergyEngine *m_AllergyEngine;
 };
 
 
