@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -39,8 +39,8 @@
 
 #include <drugsplugin/constants.h>
 #include <drugsplugin/drugswidgetmanager.h>
+#include <drugsplugin/drugswidget/interactionsynthesisdialog.h>
 
-#include <drugsbaseplugin/drugsdata.h>
 #include <drugsbaseplugin/dosagemodel.h>
 #include <drugsbaseplugin/drugsmodel.h>
 #include <drugsbaseplugin/globaldrugsmodel.h>
@@ -56,6 +56,7 @@
 #include <coreplugin/icore.h>
 #include <coreplugin/isettings.h>
 #include <coreplugin/itheme.h>
+#include <coreplugin/imainwindow.h>
 #include <coreplugin/dialogs/helpdialog.h>
 #include <coreplugin/constants_icons.h>
 
@@ -117,8 +118,8 @@ public:
         }
 
         // Show drugs database search engine actions
-        const QVariant &UID = m_DosageModel->drugUID();
-        searchEngine()->setDrug(drugModel()->getDrug(UID));
+        const QVariant &drugId = m_DosageModel->drugId();
+        searchEngine()->setDrug(drugModel()->getDrug(drugId));
         foreach(const QString &label, searchEngine()->processedLabels()) {
             foreach(const QString &url, searchEngine()->processedUrls(label)) {
                 QAction *action = new QAction(label, m_HelpMenu);
@@ -243,12 +244,12 @@ DosageCreatorDialog::DosageCreatorDialog(QWidget *parent, DrugsDB::Internal::Dos
 
     d->m_InitialNumberOfRow = dosageModel->rowCount();
     // Drug informations
-    const QVariant &UID = dosageModel->drugUID();
-    drugNameLabel->setText(drugModel()->drugData(UID, Drug::Denomination).toString());
-    QString toolTip = drugModel()->drugData(UID, Interaction::ToolTip).toString();
-    interactionIconLabel->setPixmap(drugModel()->drugData(UID, Interaction::Icon).value<QIcon>().pixmap(16,16));
+    const QVariant &drugId = dosageModel->drugId();
+    drugNameLabel->setText(drugModel()->drugData(drugId, Drug::Denomination).toString());
+    QString toolTip = drugModel()->drugData(drugId, Interaction::ToolTip).toString();
+    interactionIconLabel->setPixmap(drugModel()->drugData(drugId, Interaction::Icon).value<QIcon>().pixmap(16,16));
     interactionIconLabel->setToolTip(toolTip);
-    toolTip = drugModel()->drugData(UID, Drug::CompositionString).toString();
+    toolTip = drugModel()->drugData(drugId, Drug::CompositionString).toString();
     drugNameLabel->setToolTip(toolTip);
     // Various model intializations
     dosageViewer->setDosageModel(dosageModel);
@@ -272,6 +273,15 @@ DosageCreatorDialog::DosageCreatorDialog(QWidget *parent, DrugsDB::Internal::Dos
     QModelIndex idx = dosageModel->index(0,Dosages::Constants::Label);
     availableDosagesListView->setCurrentIndex(idx);
 
+    // interaction button
+    showInteractionSynthesisButton->setIcon(theme()->icon(DrugsDB::Constants::I_DRUGENGINE));
+    connect(showInteractionSynthesisButton, SIGNAL(clicked()), this, SLOT(showInteractionSynthesisRequested()));
+    if (drugModel()->drugData(drugId, Drug::Interacts).toBool()) {
+        showInteractionSynthesisButton->show();
+    } else {
+        showInteractionSynthesisButton->hide();
+    }
+
     updateSettings();
 }
 
@@ -305,6 +315,7 @@ void DosageCreatorDialog::done(int r)
     QDialog::done(r);
 }
 
+/** \brief Catch Enter key to validate the dialog. */
 void DosageCreatorDialog::keyPressEvent(QKeyEvent *e)
 {
     if (e->key()==Qt::Key_Enter || e->key() == Qt::Key_Return) {
@@ -315,6 +326,7 @@ void DosageCreatorDialog::keyPressEvent(QKeyEvent *e)
     QDialog::keyPressEvent(e);
 }
 
+/** \brief Update the settings of the dialog */
 void DosageCreatorDialog::updateSettings()
 {
     if (settings()->value(Constants::S_PROTOCOLCREATOR_AUTOCHANGE).toBool())
@@ -398,6 +410,7 @@ void DosageCreatorDialog::helpRequested()
     Core::HelpDialog::showPage(Constants::H_PROTOCOL_DIALOG);
 }
 
+/** \brief Open the drug information dialog */
 void DosageCreatorDialog::drugsInformationsRequested()
 {
     QAction *action = qobject_cast<QAction *>(sender());
@@ -405,9 +418,17 @@ void DosageCreatorDialog::drugsInformationsRequested()
         QDesktopServices::openUrl(QUrl(action->data().toString()));
 }
 
+/** \brief Add the selected drug as 'ForInteractionsTestOnly' */
 void DosageCreatorDialog::addTestOnlyRequested()
 {
-    drugModel()->setDrugData(d->m_DosageModel->drugUID(), DrugsDB::Constants::Prescription::OnlyForTest, true);
+    drugModel()->setDrugData(d->m_DosageModel->drugId(), DrugsDB::Constants::Prescription::OnlyForTest, true);
     dosageViewer->done(QDialog::Accepted);
     done(QDialog::Accepted);
 }
+
+void DosageCreatorDialog::showInteractionSynthesisRequested()
+{
+    InteractionSynthesisDialog dlg(drugModel(), this);
+    Utils::resizeAndCenter(&dlg, Core::ICore::instance()->mainWindow());
+    dlg.exec();
+}
