@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -31,17 +31,14 @@
 #include <coreplugin/isettings.h>
 #include <coreplugin/icore.h>
 
-#include <drugsbaseplugin/drugsdata.h>
 #include <drugsbaseplugin/drugsmodel.h>
-#include <drugsbaseplugin/drugsinteraction.h>
+#include <drugsbaseplugin/idruginteraction.h>
 #include <drugsbaseplugin/drugsbase.h>
-#include <drugsbaseplugin/interactionsmanager.h>
+#include <drugsbaseplugin/interactionmanager.h>
 
 #include <drugsplugin/drugswidgetmanager.h>
 #include <drugsplugin/constants.h>
 
-
-// include Qt headers
 #include <QMessageBox>
 #include <QApplication>
 
@@ -119,7 +116,6 @@ bool DrugInfoPrivate::checkSent()
     return sendingMessage;
 }
 
-
 void DrugInfo::accept()
 {
     if (d->checkSent())
@@ -152,14 +148,13 @@ void DrugInfo::setDrug(const QVariant &drugUid)
     d->listWidgetInteractions->clear();
     QString display;
     if (drugModel()->drugData(d->m_DrugUid, Drug::Interacts).toBool()) { //mfDrugsBase::instance()->drugHaveInteraction(m_Drug)) {
-        d->m_InteractionsList = DrugsWidget::DrugsWidgetManager::instance()->currentInteractionManager()->getAllInteractionsFound();
-//        d->m_InteractionsList = mfDrugsBase::instance()->getInteractions(m->drugData(d->m_DrugUid, Drug::CIS).toInt());
+        /** \todo code here */
+//        d->m_InteractionsList = DrugsWidget::DrugsWidgetManager::instance()->currentInteractionManager()->getAllInteractionsFound();
         // populate the listwidget with founded interactions
-        foreach(DrugsDB::Internal::DrugsInteraction *di , d->m_InteractionsList) {
-            new QListWidgetItem(drugModel()->drugData(d->m_DrugUid, Interaction::Icon).value<QIcon>(), di->header(), d->listWidgetInteractions);
-        }
+//        foreach(DrugsDB::IDrugInteraction *di , d->m_InteractionsList) {
+//            new QListWidgetItem(drugModel()->drugData(d->m_DrugUid, Interaction::Icon).value<QIcon>(), di->header(), d->listWidgetInteractions);
+//        }
     }
-
 }
 
 void DrugInfoPrivate::on_listWidgetInteractions_itemSelectionChanged()
@@ -178,8 +173,8 @@ void DrugInfoPrivate::on_butIAMSend_clicked()
     // prepare message to send
     QString msg;
     msg = tr("Testing : ") + "\n";
-    foreach(DrugsDB::Internal::DrugsData * drug, drugModel()->drugsList())
-        msg += drug->denomination() + "\n";
+    foreach(DrugsDB::IDrug * drug, drugModel()->drugsList())
+        msg += drug->brandName() + "\n";
 
     // manage INN (DCI)
     if (chkAllInteractionsFound->isChecked()) {
@@ -213,9 +208,9 @@ void DrugInfoPrivate::on_butIAMSend_clicked()
         (chkAllIAMTextsOK->isChecked()) &&
         (chkAllCATTextsOK->isChecked())) {
         msg += "\n" + tr("Checked interactions : ") + "\n";
-        foreach(DrugsDB::Internal::DrugsData *drug, drugModel()->drugsList()) {
+        foreach(DrugsDB::IDrug *drug, drugModel()->drugsList()) {
             Q_UNUSED(drug);
-            foreach(QVariant code,  drugModel()->drugData(m_DrugUid,DrugsDB::Constants::Drug::CodeMoleculesList).toList())
+            foreach(QVariant code, drugModel()->drugData(m_DrugUid,DrugsDB::Constants::Drug::CodeMoleculesList).toList())
                 msg +=  code.toString() + "\n";
         }
     }
