@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -20,10 +20,11 @@
  ***************************************************************************/
 /**
   \namespace Views
-  Contains some specific views.
+  \brief Contains some specific views and models to use with the views.
 */
 
 #include "listviewplugin.h"
+#include "viewmanager.h"
 
 #include <coreplugin/dialogs/pluginaboutpage.h>
 #include <utils/log.h>
@@ -41,6 +42,7 @@ ListViewPlugin::ListViewPlugin()
 
 ListViewPlugin::~ListViewPlugin()
 {
+    qWarning() << "ListViewPlugin::~ListViewPlugin()";
 }
 
 bool ListViewPlugin::initialize(const QStringList &arguments, QString *errorString)
@@ -49,6 +51,7 @@ bool ListViewPlugin::initialize(const QStringList &arguments, QString *errorStri
         qWarning() << "ListViewPlugin::initialize";
     Q_UNUSED(arguments);
     Q_UNUSED(errorString);
+    Internal::ViewManager::instance(this);
     return true;
 }
 
