@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,10 +19,18 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
+ /** 
+   \class Print::Internal::DocumentPrinter
+   Wrapper to the Core::IDocumentPrinter. The instance is created by the 
+   PrinterPlugin class and can be accessed by the plugin manager object pool.\n
+   The patient tokens are managed by the Core::IPatient object before the 
+   print process starts.
+*/
+   
 #include "documentprinter.h"
 
 #include <coreplugin/icore.h>
@@ -94,12 +102,19 @@ void DocumentPrinter::prepareHeader(Print::Printer *p, const int papers) const
 {
     QString header;
     if (user()) {
-        /** \todo wrong papers */
 #ifdef FREEDIAMS
+        Q_UNUSED(papers);
         header = user()->value(Core::IUser::PrescriptionHeader).toString();
 #else
 #ifdef FREEICD
+        Q_UNUSED(papers);
         header = user()->value(Core::IUser::GenericHeader).toString();
+#else  // ALL OTHERS
+        switch (papers) {
+        case Core::IDocumentPrinter::Papers_Administrative_User: header = user()->value(Core::IUser::AdministrativeHeader).toString(); break;
+        case Core::IDocumentPrinter::Papers_Prescription_User: header = user()->value(Core::IUser::PrescriptionHeader).toString(); break;
+        case Core::IDocumentPrinter::Papers_Generic_User: header = user()->value(Core::IUser::GenericHeader).toString(); break;
+        }
 #endif
 #endif
         // replace user's tokens
@@ -126,6 +141,12 @@ void DocumentPrinter::prepareFooter(Print::Printer *p, const int papers) const
 #else
 #ifdef FREEICD
         footer = user()->value(Core::IUser::GenericFooter).toString();
+#else  // ALL OTHERS
+        switch (papers) {
+        case Core::IDocumentPrinter::Papers_Administrative_User: footer = user()->value(Core::IUser::AdministrativeFooter).toString(); break;
+        case Core::IDocumentPrinter::Papers_Prescription_User: footer = user()->value(Core::IUser::PrescriptionFooter).toString(); break;
+        case Core::IDocumentPrinter::Papers_Generic_User: footer = user()->value(Core::IUser::GenericFooter).toString(); break;
+        }
 #endif
 #endif
         // replace user's tokens
@@ -158,6 +179,24 @@ void DocumentPrinter::prepareWatermark(Print::Printer *p, const int papers) cons
         align = user()->value(Core::IUser::GenericWatermarkAlignement).toInt();
         presence = user()->value(Core::IUser::GenericWatermarkPresence).toInt();
         html = user()->value(Core::IUser::GenericWatermark).toString();
+#else  // ALL OTHERS
+        switch (papers) {
+        case Core::IDocumentPrinter::Papers_Administrative_User:
+            html = user()->value(Core::IUser::AdministrativeWatermark).toString();
+            align = user()->value(Core::IUser::AdministrativeWatermarkAlignement).toInt();
+            presence = user()->value(Core::IUser::AdministrativeWatermarkPresence).toInt();
+            break;
+        case Core::IDocumentPrinter::Papers_Prescription_User:
+            html = user()->value(Core::IUser::PrescriptionWatermark).toString();
+            align = user()->value(Core::IUser::PrescriptionWatermarkAlignement).toInt();
+            presence = user()->value(Core::IUser::PrescriptionWatermarkPresence).toInt();
+            break;
+        case Core::IDocumentPrinter::Papers_Generic_User:
+            html = user()->value(Core::IUser::GenericWatermark).toString();
+            align = user()->value(Core::IUser::GenericWatermarkAlignement).toInt();
+            presence = user()->value(Core::IUser::GenericWatermarkPresence).toInt();
+            break;
+        }
 #endif
 #endif
     }
@@ -177,7 +216,7 @@ void DocumentPrinter::setDocumentName(Print::Printer *p) const
 bool DocumentPrinter::print(const QTextDocument &text, const int papers, bool printDuplicata) const
 {
     Print::Printer p;
-    const QString &name = settings()->value(Constants::S_DEFAULT_PRINTER).toString();
+//    const QString &name = settings()->value(Constants::S_DEFAULT_PRINTER).toString();
     if (!p.getUserPrinter()) {
         QPrinter *print = new QPrinter;
         print->setResolution(QPrinter::ScreenResolution);
