@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -70,6 +70,7 @@ SaveRestorePage::~SaveRestorePage()
 QString SaveRestorePage::id() const { return objectName(); }
 QString SaveRestorePage::name() const { return tkTr(Trans::Constants::USER_DATAS); }
 QString SaveRestorePage::category() const { return tkTr(Trans::Constants::SAVE_AND_RESTORE); }
+QString SaveRestorePage::title() const {return tr("Save / Restore / Import / Export user's datas");}
 
 void SaveRestorePage::resetToDefaults()
 {
@@ -199,7 +200,7 @@ void SaveRestoreWidget::on_saveButton_clicked()
             continue;
         }
 
-        while (inFile.getChar(&c) && outFile.putChar(c));
+        while ((inFile.getChar(&c)) && (outFile.putChar(c))) ;
         if (outFile.getZipError() != UNZ_OK) {
             Utils::Log::addError(this, QString("QuaZip error while setting content : %1").arg(outFile.getZipError()));
             error = true;
