@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -457,12 +457,13 @@ public:
             qWarning() << "saveModelDatas :" << start.data().toString();
 
         QSqlDatabase DB = QSqlDatabase::database(Constants::DB_TEMPLATES_NAME);
-        if (!DB.open()) {
-            Utils::Log::addError(q, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
-                                 .arg(Constants::DB_TEMPLATES_NAME)
-                                 .arg(DB.lastError().text()),
-                                 __FILE__, __LINE__);
-            return;
+        if (!DB.isOpen()) {
+            if (!DB.open()) {
+                LOG_ERROR_FOR(q, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
+                              .arg(Constants::DB_TEMPLATES_NAME)
+                              .arg(DB.lastError().text()));
+                return;
+            }
         }
 
         QModelIndex idx = start;
@@ -588,19 +589,20 @@ public:
         QVector<int> toReturn;
         QString req;
         QSqlDatabase DB = QSqlDatabase::database(Constants::DB_TEMPLATES_NAME);
-        if (!DB.open()) {
-            Utils::Log::addError(q, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
-                                 .arg(Constants::DB_TEMPLATES_NAME)
-                                 .arg(DB.lastError().text()),
-                                 __FILE__, __LINE__);
-            return toReturn;
+        if (!DB.isOpen()) {
+            if (!DB.open()) {
+                LOG_ERROR_FOR(q, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
+                              .arg(Constants::DB_TEMPLATES_NAME)
+                              .arg(DB.lastError().text()));
+                return toReturn;
+            }
         }
         QHash<int, QString> where;
         where.insert(Constants::CATEGORIES_PARENT_ID, QString("=%1").arg(idCategory));
         req = templateBase()->select(Constants::Table_Categories, Constants::CATEGORIES_ID, where);
         QSqlQuery query(req, DB);
         if (!query.isActive()) {
-            Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
+            LOG_QUERY_ERROR_FOR(q, query);
         } else {
             while (query.next()) {
                 toReturn << query.value(0).toInt();
@@ -617,12 +619,13 @@ public:
             return;
 //        qWarning() << "deleteRows" << m_CategoriesToDelete << m_TemplatesToDelete;
         QSqlDatabase DB = QSqlDatabase::database(Constants::DB_TEMPLATES_NAME);
-        if (!DB.open()) {
-            Utils::Log::addError(q, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
-                                 .arg(Constants::DB_TEMPLATES_NAME)
-                                 .arg(DB.lastError().text()),
-                                 __FILE__, __LINE__);
-            return;
+        if (!DB.isOpen()) {
+            if (!DB.open()) {
+                LOG_ERROR_FOR(q, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
+                              .arg(Constants::DB_TEMPLATES_NAME)
+                              .arg(DB.lastError().text()));
+                return;
+            }
         }
         QString req;
 
@@ -783,6 +786,7 @@ bool TemplatesModel::isDirty() const
 
 bool TemplatesModel::setCurrentUser(const QString &uuid)
 {
+    /** \todo upadte template model filter */
     return true;
 }
 
