@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -51,7 +51,6 @@ TemplatesPreferencesPage::TemplatesPreferencesPage(QObject *parent) :
         IOptionsPage(parent), m_Widget(0)
 {
     setObjectName("TemplatesPreferencesPages");
-    checkSettingsValidity();
 }
 
 TemplatesPreferencesPage::~TemplatesPreferencesPage()
@@ -63,6 +62,7 @@ TemplatesPreferencesPage::~TemplatesPreferencesPage()
 QString TemplatesPreferencesPage::id() const { return objectName(); }
 QString TemplatesPreferencesPage::name() const { return tkTr(Trans::Constants::TEMPLATES); }
 QString TemplatesPreferencesPage::category() const { return tkTr(Trans::Constants::TEMPLATES); }
+QString TemplatesPreferencesPage::title() const {return tr("Templates preferences"); }
 
 void TemplatesPreferencesPage::resetToDefaults()
 {
@@ -97,7 +97,6 @@ void TemplatesPreferencesPage::checkSettingsValidity()
         if (settings()->value(k) == QVariant())
             settings()->setValue(k, defaultvalues.value(k));
     }
-    settings()->sync();
 }
 
 QWidget *TemplatesPreferencesPage::createPage(QWidget *parent)
